
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']

def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    ...


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    ...


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    ...


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\x88*\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00H*\x00\x00\x00\x00\x00\x00\xdeE\x1cp\xeb\xa2\xfc\xaaf\xf2rn6\x89*\xbb\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=T\x9eL\xe1N\x15\xf6\xa5&\xaf\x94\xc8\xdc\xff\x9fJ\x9b\x95K32\xa5\xaf\x07\xc3v\xd4\xb81jGk\xcc\x91Fp%a\xac\xe0\xbf\x11\xb9h\xf5\xff+'
        b'\xff\xa2\xa8\x11i\xaf\xc9\xb3\xfe\xd2!\x14V\x1a\xec\xf7e5\xb9\x1eu:B\xa2\x199\xbe\xfbkYD\x08o\xaa\xd3\xac>\x880\xdd\xf3 \x82M\x8d;\xd0\x93<\xc4k~\xb4\x97"\x99\xa7\xa8\xd6\xb2\xe3*\xa2/'
        b'\x81\xdf!C\xdc#wH8\xde<,zU\xe6\xa7\x07.\t\x97\x99}\xfb\xa9e\xf8\x9d\xcf&\xcc\xb0\x96H\xe2\x83"\x82l\xe8\xfe\xee,\xf2\xf5\t\x82J\xaf\x134=\x87P\xee\xe9\xb7"\xcf\x81"\x1f\xe1\xa7\xd4'
        b"\t\xb7\xd4\x1c)\xf4\xcb\xfd\x11\xb2\x82,\xe0\xce\xf9[\xbd\xdb\x83';\xda\xaalj&u\xd9\xa6\xfb\x8a)9b\xf4\xf6\x83\xb2\xf1pD3b\x9d\x8f\xb5\x1e\xad#\xe1v\xa6\xfa\x8dO\xbc;\xe5*\xfc\xfb~@\x81"
        b'6|\xe5q?+\xe3\x17&8*\x9a\xafs\x10\xe3~\xdd\xdb\xe8\xf6\x98\xf7\xfb\x93\xc3\x91\xe8X\xee`=\xfe\xed\x01L\x9f#\xa3\xad\xb8\xd0@\xce\x07\xe5V\x19\xe9\xdeG2\xbe\x180\xe9$dU\x0b\x00<\x14\xb9'
        b'\xde\x01C\xfd\xba\xfa{\x93\xe5\x05\xec\x8b\xe1x\x962\xc7\xf3~\x1b\r\x94\x02\xeef*m\xe4\x14=\x19XH\xb1~*\xcc\x7f\x9b\xe1\x9a\xcc\xbcQ\x16l\x1c\x92\x8ff\xacV\x941\x95K\xad.\x8f\xe1g\x03\xd6\x1c'
        b"Q\x06W\xa8\xef\xc3B'\xc8\xc5\\@l\x8ca\xeb\xbdS\x88\x98\xd9\xd6\x11wiHC\x9e\xfby\x01\x8a\xc5a\x15\xeb\xf6 \xa4\xa5v\xb7\x9e\xf21\xef\xbeZB\x13`\x87_N\xd6KH\x83.#=I\xc9\x0b"
        b'\x85.3\xe7m\xb0\x7fOPX\x80\xfb\xfe\xc5\x93o\x9f>|\xc0\xe0\x03&6\xa8Pw\xda\x88\xca\xde\xe8\x89\xe3\x92\xe5\xadu\x8d\x9d=\x0e&S\xf1n\xd1(\xcf\x8b\x9b\xe2\xb0\x00\x8f7[8\x95\xef\x8d\xd2\x10\xee'
        b'\x92:^F\xcaQ\x89_\x88\xca#\xae\x9b\xb5\xf3\xa1\xe8\xb1\xb5\x06W\xf6\x14J8s\xa3\x97\x89\xe8\xb3\xd8\xf0\x1c"\xc1\xefj\xe9\x02:I(\x11\xd89K\xed<RJ\x83\xc8\xa6\xc9\x10\x06\x15\xf6\xcbQ\xc16\x11'
        b'j2Q\x9ed\xa9\xe1\xbb\x1b\x06\x19\x89\x95%DD:\xee\xae\xfa\xdf\x0f2.XU\x0b<\xdf\xaf\x90k3\xc0\x1b\xfe\x9c\xe0\x90k\x961\xf2\xbc\xbet\xf8L\xfd\x10\x05\xebH\x99\xec\x8d\x14\xbf\xf1\xdb\xc3\x7f\x8bd'
        b">\x81\x98e+\xcb\xc4\xae#\x83\x89s\x97k<\xabU\xb9\x82\x7f\x87\xa0\x87\\x\x08\xc7\x9d\xffT\xb4}\xdfP\x1by\x0c\xae\xbe0\x82'\xb7^\xdcY\xae\xc4\x9cB\xe8\x1bW,\xf0\xad \rO\x81\x89%\xa8\xfc"
        b"\x93\xfbq\xcd\xd5\xe4\xf9\xd3b{{%z\xdb\t\x8b!\xb8p\r=\xcb\xc7Rh\xe8LlF\x10\x97\xad\xffe\xf0\xa9\x9c\xbb\t\\@\xff\xd3\xf6]\xec\xa6ig\xbd'\x97|\x8c1@:8<o5%sx"
        b'Z\x12\xb4\x8e\xaa\xe1\x9c/\x14#s\xf1\x05W\xf5\xa4\x81\xf7"m$&R\xd1pm\x04M\x92\x92\xf8T\xb2\xdd\x95\x13\xba\x91\x84\xdf\'o F\xb2 \x04>Z\xeeS\x92\xeb\xc8\xac\x91\xb1\x19\xcc\xc0 A\xc1\x83'
        b'\xc0\xe4\xd0u\xbbD=j\xa8\xb1zj\xa9pE\x7f\xe4J\xa0\xa2\xf6D\x18x\xdb\xad\xdd\xc3\xc9\x97\xadp=\x82\xddL:\xb7\xba\xdf\xbcn\\\xeb\xde^\xe9G\nm\xfe\x13\xc8]\x99\xbb\xb7B\xb8\xef\xb8kM\xe7'
        b'\x95\xe3w\x9c\xa8\xbc\xea\xa3\xef\r\xe2M\xe8p>\xf4\xda4\xfa\xeb\xc9Jl\x87SW\xf12s\xa8\xa6\x07\xaf\x86\x00\xf8\x8f_\x1e\x80\x95\xf9\x8d\xf3\x84\xf2\x80\xf3\xcb\xcf7\x15\x86\xc9\x07\xfb=c\xbc\xe1\x00\xdc\x01,'
        b"\xb6'\xc8R\x03\x85+iS0\x80\x91\xe0,\xcbk^M\xa9\xae\x80~\xee\x0f\x84\xb6\x83A>\xa1u2o|\xb8\xd6Yf\n\xc0\xff#i\xc8\xd0\x0bD\xfe\xed\xf4j`\x04\xbc\xf8=\xea\xa0+\xd5)\xa7=\xb9"
        b'j{-Hy\x96PRp\x81o\xb7\xe2\xc8mU\x9d\x91Kb%\xc2\x7fs\xebu\xf8\x992{x\xbehJ\xe5\xd3\x08\xb7\xcc\xc6s\x1d\x01\xa5ew\xe3\xf8\xa5P&\xcb\xc1\xe2\xf0#\xe5\x90\xd4\xf4\xc5\x11\xb6\xc2'
        b' t\xd0\xb3\\\x96\x14\xae~x\xb5\xd1\xd5\xd4\x1e\xde\xff\xcf_b\x92>\xc5\x9e]\xadW\xe6\xb0m\xd4\x13Cc\x9e\x13M\x1e\x9b\xf3\x9d\xc9\xbd\xa6\x9c/\xe2\xab\xee0\x1c\x85/Mr3\xa9$\xda\x19\xe3u}\x1f'
        b'\xeaL\xfd\x93\x0e\xad\xc2\xeaMF\xca\x8c\xce\xa1\x16\xc5H\xc6\xece\xc6\r*/\xcdo\xbf.fQ\xa8\\j\xab\xb1\xbb\xd3\xc6Jo\x92w\xae\xa6\x96\x13\x1e\x19\xff\xe6o\xb9\xb8\xdf2}Y0Q\xed\xcd\x1d\xd8P'
        b'\x81\xb6N\xb4\x91\xe8\x81yo\xdei\xab\xa0%\x85\xabK\xe9B\x12\xca\xfc\x90vX\xf0\xc2M\x81\x03|T\xb4\x81?\x124\xe8*lg\x03\xe1\xaa\xe8\xaa\x8b\xed\xa1\xbd\xda\xc6XJ\xd4r\xef\x14`B.t\xf2\x80'
        b'\xcf\xad\xdd\xfdhp&^R7d#\x07\xf31\xd0M\xeds\xd8\x95\x8d\xe9%\xe1\xaew\x12\x0e\xdb\x85\x84\xe7\xdf\x0cP\xb9Z\xa90\n\x99\x86\x82:\xe6\xb3\x04\xd7\xb0\xc3\xb4zr\xd2\xc4\xc3\x17Y\xa5\x12\xa9\xe9u'
        b'%\x89\xab\xf3:\xae\xe7\x86B+\xb8\xf8\x1a\xc9\xb3@\xb5\xa4hm\xd94+F\xf9\xb7NQ\x14\xb1\x0b\xad\x1bvzq\xcfSt\xa0\x17\xdbxI\x18Q\xf5\xf3\xe9*\xcc\xa8\xd6\xb7Gtg\xdf\xea\x137g,\x9d'
        b'\xe6&XHX\xe0\x1b\x07\xe2~\x93\xc8n\xc2<4Q(\xbe\x18,9O\xd3\x84\x0c\x1a\xac\x03\x00?\xa6u\x11\x9e\x1a\xed\x89\x02\x00\xceaSe\xa5|\xdai\x0b\xc8\xf4\xe7So+\x89\x88AW\xfar\xa2\xde\x99'
        b"\xa9\xad\xe8\x14\x05\xd4\x94\x8a\x99\xa0\xa17\xea\xb0\x1c\r\xaeQ\xb8\xc0$\x97d\xf0t \xb60\xd1\xb8p\x17o\x94\xd5\xfb\x83\x17h\xc2`\xb2\xdc\xec'2\xa9{\xdbD\xe2,\xe6\xb6~o\xe8\xe4N\x07_\xd6\xbfa"
        b'@\xf3\xe3\x83\xec\xb7\x906\x94{\xed\x83\xffO\xd9nR\xda\xf2ZJ~\xf3<\x8a%I\x1c\xb0\xa6\xff0r\xc2*\xacg\xcf\xbeE(\x1ao}\xad\x1aYU\xb4\x96\xe8\xa8;c\x9e\xd2\xab\x88\xa5\tT\x19\xdde'
        b"\x8asw`H\x14\x82\xed\x82w\xa0\xefl\xf6Z\xe8N\xbdC\xa6c\xb9Q(\xedO\xbd\xd8\xcfA\xdc'\xb9\x892\xb3\xd0\x1b\xcf\xd8\x93)wD\x18\xf7\xdd\x8f\x0e/8=i\x10\xdcD\xef\xd4\x03\xbf\xa7\xcbJ\xf5"
        b"\xea\x02(\xbeS\xfft\xdc\xc2\xfc\xf1\xf0K\x19f\x15y7\x8f\xf2\xbd\xae\xe9R&\x0c\x9e\xa4\xb5&\x0c$\x11\x89\x9a\x95\xde\xfa\xbeVR\x99|\x7f\xc5\xa8\xed(-e\xcf]]6%'\x9a\x86_S\xd7\xb6\xc8\x80"
        b'\xe2\xf2\xd3\x02\xd7\xafS\x00|\x01\xc3w7\x00\xe8\xf0\x03\xc2\xf1*\x9c6\x04\xa9K\xaf="\x8dZ\x1d\x82\xbbP)SL\x13\xed\xa5\xdet\x01?.\xc2\xb1E\xda/\'\xe8\xb6&j\xe3\x1a\x15\xad\xe6\xe0{\xec^'
        b"\xbb\xbd\x19Y\xd4C\xe6\xab\xd2\xa1~2\x8f\x00\x17\xdb \xb6O\xbaEg\xbfG'}\xc6\xd7\x16L\xc4\x16\x95\xb5\x99\xb9{\x1c4dU\x1ac\x89\x9f\xc8Mg\xaf\xa4{\xfe\xb4\xe8\xb8\x8e\xc0\xee\xdc\xd5\xde\x1c\x1e\xe5"
        b'\xd6\x9f\xa8E\x962 \xdb\xc2\xd5~p\xe3\xc9\xd3\xc5j\x12\xd4d\x03\xdc\xc6V\xc4yT"\x99\xc8a\x8aw\xc0\x1b\x1a4j\xd3\x16\xc5\x9d\xdb\x13\xac\x86M\xc9\xa0\xf4\xa94u+\x06\x12\x8a\x0b\xd2\xbd\xed\xa2\xfdn'
        b'\x18\x90\x94\x97\xdc\x92\x1fi\xef\x18_\xbf2\xa7d\x91lS4\xce\xd6\xd6\xaeS\xda\x1e9Y\x1e\xf8\xc5}M\\\xa2\xff+\x1a\x08\xd8=\xf0P\xac\xc5\xa3\x1f\xcaM\xd2\x1b\xe7B\xeeT=^p\t\xfc\x81[\x91\xf6'
        b'^\xd4\x89\x87E\xc3\n\xcc\xe9\xe8\x94\xc9\xf7\xc6\x1a\xe7\x05\x06\r\x9d|\n\xb69\xcbH\xfd\x07\x175\xec\x12\xd2\xb2,o\x16\xa35\x0e\xc9w\xd1\xc6\xca\xdd}\xee\x18\x12u\xaf\x12\xe5\x81\x91-\x03\xcd\x82X\x1d\x87\xb5'
        b"i\x82\x9e\x8d\x18\xe6}\xdez(\xc9R\xcc\xfb*#\xdb.\x0f_*\xef\x0b\xa4\xea\x7f;\x0e\xc07\xd6'\xec\x8eqK\x1f\xfe\x14\x89\x94\xd9\xa2\x03\xb0\xd1Z~\xc0\x9aP\xa4\x7f\x94\xfe\xf6\xc3\x80\x14T\xa26\xbc\x13"
        b'\xb5\x0fX\xbd\xfa\x15xr\x0e\xa8\xe9|d$wO\xbd\xd1\x1f\xc0\xd5\x1c\x0c4v\ts\x88\xbeF&,\xbb\t[\xcf\xae\x1e\x1b-\xc6UDN2\x81\x1a\xf3\xce\x86\xdd\xf7\x1b1\xc0Q\x1d\xb82\xd7\xe2@\xde\xf3'
        b"Z\xd3\xed\xf2/'\x06\xcd\xff\x0eF\xcfF\xa0\xba/\xb6\xee\x94\x9e]\xc4\xbd\xca\xd8\xedx\xbf/m\xf8K\xa7\xc3\x86G\x81\xbd)S\x99\x8a\xb8\xc3\x9e\x9d\x80\\\xd4\x95\xc9\xf9v8u\x1d- \x0c\x95kZ\xce\xaf"
        b']w\x05\xfc\xfe#\x96B\xa3\x04m\x1c\x11E\xb6\xe0a\xdf\xce/\xb7\x86\xda\xadyU\xa9\x08\x97\xee!\xcb\x17\xc7\x90v\xb4\x8c\xc2"P\xed\xbd\xbf\xb1\x00\xf8u\xbc\x9a\xbc\x8d\x91\xdc\xb3)\xf7\xa0oq\x1d\xee\xc9b'
        b'\xc98\xa0N\xb2\xe8\xdc\xb2p\xde7\xbe6T\t\x8eh\xbc\x95k\xe5D\xa4Kb\x8cw\x94y\x10\xa8\x14\xf3K\r1\xdd\xf4\x15!Af\xbcV\xca\xb2\xee\xc3m\x12\xe8/l]\x07\xf9\xb5\xd8z\x10\xfa\x88\xcf\xe9'
        b'=\xad\x8f\x96\xb7\xda\xd2\xbd\t\xfd\xfe-\xd5\x82\x08\xa0\xb1\xeb\xbaj%_+\x9b\x9f\xce[\xc2\xcae 8p\x98\x01\xfd\x0eM\x8e\xc4 \xeb.r\x13\x8b\xd9n&m\xa7\x01r\xa1+@\xa1\xb0/\x89\x06\xac\xc4 '
        b'\xc0\x98Y\xd2\xdd~9v\xafEB.\x8a\xad\'\xd5,@"\xd7\xe8N\xa4\xa9\x03\xddX/\x11\x18\xdf-c\x91\x8b\x907A\x15\xc9\xebHAp\xd4\xdf\x96\xb1\xe2}j%/\x1d\xb8\xc08:\x85\xd9\x84\xdbO|'
        b'/fyy\xf7:\xdf\x9eV\x11\xcd\xd1\xe0\x94?\xdc:\x0e\x9a \x08\xec,Z\x13\xf1\x05\x1f\x81\x85\xe2n\xf3\xe6\xdd\x19\xa0\xea\xe8\x87\x0f\x8e"=R\xa5\x053C#\x03R\x112G\x9c\xc9m\x98\xed\x06\xbbj\x03'
        b'\xa4\x91\xd1Z0\xbf~\xcd\xed\x1f\xf7\xbc\x1c\xdb\xa4\xc6\xae}M\xcf^a%\xec\xc8\xea\x02RD>\xe4\xd3>\xb0\xcc\xef\xa2e\xdf\xe6\xff\xf9\x99+P\xc5.\xaf\xbf(f\xad\x89\xe9OA\x163\xd6dA\x99\x89q'
        b'\x1e\xce\xb8s\x8f\xc8T\xf1N\x03\xd3\x8e\xfe\xc5\xbb\xec~\x18@\xe4\xbc\x98\x16\xedFk\\\xb2\x926wXu\x97\xf2\x1e\xb4Hz%M\xed\x97\x1e4GU\xb5q\x1e\xbc\xa3\xa4\xe5\xa1\xe4\xb1\xd0\xe0Qi\x8c]^'
        b'|\x82\xa5\x93\x13\xb0\xef\x13\xae?c\xf8\xc4K\xf5p.+\xf0w`4\t\xa5\x8b\xcc\x88}N\x1cP\xbc(g\xe1\x1cR\x0f\xca\xcf/\xd1\x84\x12\xfb\xe0\xee\xab\x0c\xabc\xa2]t\xb9=\xf0\xec\x8a~[\xf4b\x0c'
        b'T\xc3\x7f~\xc5\xfa\xf2\xcc\xa6\x170\xf1,!!\xdb6\xe1\x19\xf2\xd1d\x12\xc9\x10\x82\xe5 e\xaf\x19Q\x01\xf4\xc33t\xcb6\xe4UhY\xfd\xf1i\xb8q\xfa\x9e\xb1V\xb8B\xbe\xa14\xdf\xe5\xaeP|\x87\xd1'
        b"\xf3\xb1\xf4\xf3\x1c\xd9@+T\x1f\x17u\x80R\xf4\xf9J\xc6&#z\nQ7\xb5\xaa\x1b\x83u<\xed\x99Uk\r\xd6\xd0'=\x92\xe2_\xbc\x95\xe1p\xcf\x88\xe4\xb7\xc5\xb9\x9d+\xf0x\xd7Q\x13\xcbB\xfd)Q"
        b'$\xc04\xe8\x12\x1f\xe0z\xac\xab@\xe6M\xc9\x92\xc31M!\x03\x867\xeb@s\x0fl\xc5\xe9\xa2\x1dH?\xda\xc9\x8c9p\x05@4\xa6M\xe0C\x8c\xfa\xde\xf26AMn\xc6\xff\xb4QI\xea\xad~\xdb\xc9('
        b'S@\xf5\xd1\xb1\n\xab\x02\x9b\xcc\xefA\xa2\x7f!\xdb\x85h\xca\xb0\x0e{\xca1\x94\\6\xa7H\x85\x0f\xeeY\xd2o\x107\x1dE$z\x05\xe5p\xf6\xc6\x1d\x97\x8d\xc6:xhqe(\xdeH\xc7\x15)EW\xdc'
        b'\x12m\x82\xde\x80\xa1\xa0\x1c\x9c#\x89\x0c\xb3\xcc\xb8\xde\xf2 \xae\x0c\xbc\x80\xf5\xbfp\x05\x95\t\xfc\xb9;\xf3-D\xec\r\xf9\x9e\xb1"\xd3T{t<\x93\xf2\xbaH\xe5s\x9d#"/h\x84\x96\x96\x9d\xc2~w\xec'
        b'(\xa7\xa7\x00n\xe6\xfd`\xddLo\x8f\x05\xaeg\xcc\xf5\xa8\xeae0\xff-E\x1e\x0cQd\x14\xf7 \x15\x14\x17\xfc\xb7\x14(\xb6\xc0c\xa4\xdds0\xb5lx\xe9K#xJ\x93\x03\x1e\xec\xd9\x18\xb9\xa2\xba\x8c\xfd'
        b'n\t\x86\x9e\xa4\xe7\x8c\xa7\x9e\xea\x90\x85/\x92\x04\xbd\xa8\x98gR{o\x9dG\xc3Y\x08\xc7W\x8a\xe1\x1c\xb4<\xab\x18\x9f-\xf0\xb5H\xdb\x87\xb84\xbe\x1f9\xbf]\xd7\xc7\xcf:\xe0 Q\x91\x9cXO)\xee\x03'
        b'TF<\xe2\xdf\x07\xf6\x06f\xeb\xab\xd2\xa3\xda=\xf9\xc1\x1d\x12T`\xc0~B\x92\x06\x87\xd3\xb7>w\xf8\x11\xf20\xa2\x82i\xa7l;\xea\xcdU\x9a&t\xba\xc3\x1b\xda\x84\xfc_\xd0\x99.\x90\xbc\xb5\xa9\x17\x1f\x80'
        b'\xa9c\xcbd\x0e\x92\x1bY\xba\x81;\xf3\x11\xa4\x83\x13\x85\xf8\xcf\x12F\xde\xa1W\xd8\x987x=\x14\xd81XL\x13\x97\x9b\xbf@X-O\xa9\x95\x06[\x85\xef\x0cA\xca\x08]\xed\xf6\x00`\x17\xbfJ\xecqd%'
        b"\x9bRTL\xbbu\x1f\xba1\x94 @\xa4<\x1bl\x18*\xb7e\x8b\x80\x96A\x99\xf5R\nT'\x17\x80\x125\xc0\xac0@\x87G4^\xe3\xef\r`\xf6\x81\x9fe\x01\r <\xe9gE\x84\xb9\xcf\x18<\xffJ"
        b'\xda6\xde\xc0\x90k\x01\xf2}N\xe6W\xef\x14\xc3\x87\xa5\xc1\xe2Ku\x0b0X\x01D\x14\xcb\xb9\xfa\xc3,\xd2W\xb6\x05\x1b}^\x90_%o\xd2\x7f\x82\xa4\x83\xa0\xe7\xc4\xff\x81*$\x93\xd4\xba\x8b]\x86j\xd3\x17'
        b'\xf7\xd8\xfc\x8b\x04\x1d}\x82\xea+\x1c\x0ef\xda%&Z5\xef\x16rKr\xe2\xec=x\x1e\xa1\xa9z\xbc\x08\xbe\xfd\x94!\xf6<\xb5A\x1d\xeb\x1d\xbd\xb2\xbe\xad\xe7]@\xc1/\x18\tK\xea\xcf7J\x11q\x1f\x8d'
        b"\xb0\x89Sf\x0e\x1e-'cb\x80\xbc\xeeA\x0c\xd0\xc9G\xf4\xcd\xba\x00)?\x0c\x1b\xf1n\xd4\x06F3\xf0\xa9\xf1\x0fLF\xda\x06<\xa0\xb6\x96\n6n\xdb\x8f YD\xfa\x9aC\xe41\xc2\xfc\x82\x803\x92\xef"
        b'C\xdd6\xf7;\xa9\xfe\x9d\xe6n\xe7\x00\x83.\\w\xbe]\x8f\xfc/o\xe5\xb6\x08Nn&K\xaf\xfa<\xd6\xa1\x80\x0c\x8d8J\xe4g\xf5@ \xe7Z\xa1\xa1\xbd\xca-?u\xb6\xa3\xaa\xe3\xf0\xa2\t\xaa""\xa1'
        b'aw\xbbU\x88\x8f\xc7y=\xf6.:\xbbSg4?\x9a\xf1\xf52\xf1\x7f\xe0=\xa5\x0c8\xa2L\xf2nc\xb9\xd4\x8b\xf5K\x8d\xc8>ggO\x8c\xa4\xc4\xa6\xe9\xcc\x0eq\xa2V\xed\xafv\x90\xac\xa9\xf3G\xe7;'
        b'\x00\xc7\xd1\xf4%\x11!\x95\x90\xd27\xad\xd0qwF\xf3n\xed\xc9^\xb6Fh/4\xae7\x06\x028:e1\xa8\xad\x90\xe3\xd6\xb3\xa8\x98F`\x06!m\x90z8C}\x1b\n\x1c\xac\xa3\x8e\x7f)\xa0\xf9C\x83'
        b'\xa7\x1ek\xfb\xe0^\xe8\xc1\xb2\xf8Z)\xc2\xfa\xd0\x16\x98\xbc\xf2"5\xd1\xe1\xb8yB\xfd\xd1s\x97\x91\x8fF:\x0c\x8d\x95V\xbd\xc4\x94\x15cH^+\x8a"=\xc9\x02\x94\x11\xd3\xc74O\xe9&\xf8\xea\xf2\x84P'
        b'R\xbb\xff\xda\xb9\xbf\xa9\xf1\x94\x94jo\x81\xfb\x1fB\xb1R\x86.I\xef%l\xb63huM\xaaK\x98\x81zfQ\nG*\xa7\n $\x02\xbfR:\x7f\xb9\x1b\xe3\x85>@kpIF\x15d\x05\xc4\xf8\xf0'
        b'\xd2\xf55\r*\'\x8d\x05`S\xfb`\x0c\xd6\xc8\x94\x89\x98R\nYh\xfe\x93Me\x0c\xc8\xba"\x03\x1e\xd6\x08\xf2\xc0\xf4zw\x176m\x99\xd6K\xcbu?-\xf6\xa6\xfb\xcbX,.Y9\xe9%\xefy\x02\xea'
        b'"\x0fZ\xd5\xae\'\xbc\xc9\xca\xde\x07\xb2t~\xa7\xe2\x02\xf2\xd4\xd8\x904\xff\xe6\x8e\xdd\xcd\xe7\xd96\xa8\xb51\x0c\x98\x9e\xa2\xbd\xb73\xb5]1\xcd?#s\xdc[\r\x16\xf3\xc4\xc4\xec\xf8\x8f\n\xcbY\x14\x8c.;'
        b'\x10\x80\xb5\xc7\x11\x1c\x1e\x08~S1\xa0\x13\xbcl;a\xa0\x1a\x0c\xe5J\x15\x17\xb0\xe4\xbd\xc6v>+d\xbbp7\x08\xa46s\n\xa2\x1d\xe3c\xfa\xa35lT\xc5\n\x0f+Sv\xe7_X-\x08\xa9\x1do}'
        b'\xfd\x0f!\x915\xd97%g6LG\xe9?\x94\x92\xfb"\x05\x1bO\xa6i*\xb1R\xf8z\x8ez\xaf\xe0\xe7\xc41\xc5\x9b\x84\xccKtr\x05\xec\xaf\xfbj\x0cT\x05\xba]\x1d@\xc4\xa6\xa3\xado\'\xf4u\x12\xb5'
        b'\xad\x0b\xd3\x03^\xd3\xad\xa9\x02\xb2$\x04\xa8\xab1\x13\x9fh\x9f\xbbB\x03{dA\xde\xdbmh\xa6\xa3u\x04\x90\xd0\xe0\xaa}\xed\xaf\xcb\xd7\xd9N\x1b\x14\x10\xd0\x06\xd2\x9dm\xb1\x93E\x13 .\x90\xb9\r\xac\xf1\x87'
        b'\xd6\x9f\xf0\x8dwQ*\xe6\x0f\x84\xc4\x15\x89\x97`C\x0eq5G!\xc2\x19\x80"\xa7z8Z\xb1/\xca\x9fu-\x0e\xc4)\t\xf1\xa3D\xe1\t\xcf\x19(\xb9k\x7f\xe7\xbb\xcf\xdc\xe0\xcb\x95\x8c\x96>~\xb7\x8b\xe7'
        b"\xd6\xa3\xac\x12:'D\x8c]\x02KM-g\x08\x16fE;\x19d\x90\x06\xc5\x91\xc9OF\xf9\xf0C%\x1c\xe5\xaehxNF\xd5\xe0\x1bR\xa4_\xad\xda\xf0v\xf4\xb3\xb8\xdbE[\xd9TN%;\xf9*j\xa3"
        b"\x98rX\xb7\x06\xf0\x93\x94u\xe9\x87\xd7\x02\x1eV'\xdd\x1d\xd2z\x82]\x1e\xd2\x9c^Bt\x96\xeb\xa0\xdf!Tm\x8c[\xe4\x8e\xf7\xc4\x01\xf3d\xf0\x9b,A\x8d}V\xf2\xf4'\x16\xb4>\xdc\xc84.\xf8j\x00"
        b'&\xc2\xed-q\xbc\xae&D\x8f\x1c\x8aN\xf5\x9aM\x8c\xe3\xf7\xb4\x13V\x9a\xf4\xe7\x86R\xe5\x01n\xd7\x9b\x04\xbaB\xbb\xb2\xd5\xd6\xd2\x80w\xf5\xbfs\xe61zpN\xd1N\xa6\x07*\t\xe35P\x0cz\xd2\xc0\xce'
        b'\'Hn\x05\x95/\xa9\xacK\xffkI\xdb\x89\x81\x13\xdb\xf8-\xe8\xd4\x84\x01dj\x96\xd4\x1c\x90\x90"\x11\xaf\xc4\x92\t\xf7\x96\x06\x04\x11\x18\x07F\x90\xe1Z\x8f$\n\xe8:\x99K%\xbc0\x10\xa9\x96/V\x0e\x9d'
        b'\xe5q\x89\x98;UV\xe4\xa8\xc7A\xf5&\xac8\xab\xb95\xd8\xb8Z>\xc01D\x1c\xde|\xa87#\xe6\x93y\xeb\x88\x00\xea\x16+x\xb4\x0b\xf6\x9e\xd4\xba\x1a0=g\x01GQ\xbc\x98\xda\x16\x8f\xfd\xcd\xd0\xc2\x91'
        b'P\xd9Qp\x97\xbf\x14\xe1\x06t;\xa8\xe9\xb3;\xa0\xe84\x07$\r\xb0&\xc5O\xcb\xe3\xc5 W\xd7\x90\x1d\xb9\xa9\xd4\xc3\xfe"8\x15\xda\x9a\x82\xfbN\x99\xed\xb0\xe2\x9c\xd5t\xe8\x81\xb4j\xd7\xc2\x9d\xfe\x95\xaf\xd1'
        b'\x139\xa5\xf8\x14\x10T\xda]\x905\xfc\x17_\x0b\x93w5\xbe\xcc=\x87\x8d\x0f>\x14\x80P\xbb\x01\xf9\xa83D\xe2y\x17ms\x8e}\x92\xce\xd3~\xc6\x92\xeaJ^\xea8\x14NN\xf9\xa0\x1a\xad[\xda\x94\xdb\x03'
        b'\x99]\xe3\xa1*q\x06Jc\xe0WGw#\xc8\xc8\xa9U\xaa!V\xa6^i\x1f\xbb\xbcD\xe5\xaa\x13\xe2\x85i]\xec\x07\xc4\xae\xd6\xd8\xc4\x18\xe6\xdf~\xb4\xdf\x93\xeb\x86\x84*\xcf \xe2\x06YX$\xf7\xf8\xff@'
        b'f\xed}\x94n\x80\xf8\xcf@\xc4\xb2\x89ms\xf6\xf4\x8f\x9e\xa4\x10\xe5%\xe4X\xc3\t\xd5S7#\x93r\x05/\x93\xedP\xa8\xdc\xee\x85{\xf4\x8d\x0b\xba\n\xca\x1cW1\x18\x13O\x90\xf6\xcc\x9f\x9c\tFa\x99\xc8'
        b'\xb40\x1b\xdc\xe4~}\x1dR\xc9\xdc\xb8LKf\x86\x9c\xfcr\xe6\x8c\xfe\x02\xd2\x12\x0fr\xb7\xb5\xe3\xd7\r\xcfi?\xd8\xf8\x9d\xa9\xa1\xe7w\xc8V\xeb\x0eA\xef?q\x9e\x91XhS\xda\x93\x18l\xb2\xff\xd6(I'
        b"\xf2\xf7\x9ex\xb4\xbcZ\xd5\xb7P\xb3)\xd9\x0bD\x1dy\xa9E\xe6\xc5'CRb\x01TA\x87\xab'\xcc\xa0\xff\x94\xea-\rU\xd9{\xdd03>\x8e\xd6\xda\xbd\xa1n1\x00\xc6I\xc7\xed\xfeO\x96\xeb\xe0/V"
        b"\x1f\x8fG\x05$\x87t]_\x9f\xa2f\x18/j\x94\x13,\xa4\x8e\x93On\x97W\x83\x95\xe8-\x8a\xd5\x907\xa7\xe6\xd0\x0ee\x90\x12`\x19\xe6\xdcL'48m\x9c@\x14\xb8\x95\xb2\xcf\x91\xef\x1a\xcd\x18~c?"
        b'Fu\xfdC\xaf\x05I3\xc5\xfb\xa4*\x0e\x03\xdb\xb1\xf0\xe0\xc1uO\x0c\x99\xabYe\xd4\xefvdX\xa3\xaa\xffU\xaf\xa3\x04\xdew\xa7\xe7%\x9c0\x01G\xd0\xb0]\x1cH\xd8\x10\xe5\xee\xafc\xa7lul\xc9\xe2'
        b'\xad\x1e\x96*\x05p\xb4c\xbf\xdfo\x02\xa1E\xd2\x02\x93\r^\x93\x02vm\xee\x99\x92\xedP\xa3)\xd2\x90\x18D\xbc\x9c\xebb,_\xd8f\x9bz\xc8v\x13\xab\x1fF:\xbc\x98\x9a\xebM[\xfd\xc8\x03\xc4b=\x85'
        b'\xbf\xab\x89\xfc\xe6-4\xb7\x91\xe1NH2~\x06%O\xe9\x86n\xf6\x93\xc8\xcdT \xb9\xba\xc3\xfcvC\x82\x10n"s\xf4N8\xb7\xc4\xcf\x14F\xc9\x12\xdd\x92\xdb\xcfh\xb4@\x80\xc3\xb4 qJzJ\x1e('
        b'mD\xa5\x88%\xaa\x95\xabRq\x05\xf9sv\xec2-\x92\x98\x9aS\x89%\xb4\x97%\x7f\x15\xb9\x1a)\xb0\xd7J\x07y\x16\x1d9\xbb[\xbf\xca\xff~\x96d\x7f\xcfi2\x1c\xeeZ\xa1\x81\xa9\xb5\xc6\xd6\xe0\xa3\xef\xe1'
        b'\xb28\xdb\x1e\x84\xb5=[X?\xc8\xf0\xf7\x16\xe4\xdc\xfa\x80\xe9[R\xcbwLYR\x8c~\x91\xab7H\xad\xbd\x15\x05)\xfb\xd42\xcf\xe4)\xae\x15\x15\xec\x9d\xa2\x9cZ#\xb1\x82\x90e\x16\xa6]\x86\xcdywQ'
        b'\xb8\xd2\xa0\x8c\x9a$\x90IV\x80 \xfe^\x11m\xe0\x83\xb8e\x01\xa1\x97R\xfd7`\xc7,f\x1d\xf4\x89\x90\xf2W\xa9\x15b\x1b\x07\x15\x97\x1b\x9b\xe7/\xc0$\xca6\x86\xd0\xda\xe3\xac\xaf\xc6XL\x18\x18z\x0b\xf3'
        b'p\xeb\xc1\x95p\x81\x06\xd5l2 l\x0e1\x98\x9c\xd7\x1a\xf8$|\x0f;,1\rq\x90M\xdd\xef8\x11\xc5\x14\xeb\x89\xc9\x87\xafaZ\x7f\x14\xc19J\xdcB6S)\xc6\xa7M\xfb\x97\xbbV\xbbS1\xf5}'
        b'\xfaVo\x03-m\xefU\xc551\xb9\x0e\xd1\x87@E\x9a\x9c\x1a\xb8V`\xc3\xceuKU\xcc\xf0S\x85\x14.\xcf\xe6\xe5\x8bS\x8f\xd6\xfe\xd9\xf8o\x9bp\xd1\x16\xffR\xb3]\xb4%d\x08Y1\x06>\xb3Nl'
        b"g`RE\x99B^-\x8a\xa9\x7f\xa2\x84\xf2*\x19*\xbb\xa2\x95\x11\xe2\x0f\x83\x9f\xef1'\x873\xb1x\xf0\xc7+l\x11\xbe\x1f;\x8fP(\x85\xa5X!UT\x9b\x15\x93\x85P\xf8\xf1r\xe6\x84\xcc\x18\xde\x05."
        b'+n\x18D\x1a\xed\xf1\\\xedl\x88r\x84\xa2q\x83\x91\x11\xde\x01\x0f\x0c\xde\xa6oPu\xb3 \x8d \xf3\xd1\xe0`5\x1e\xa6\x14\x1d9[!\x8e\xbf\xdf\x171?\xd9\xdb\xe0<ly@`\xd5 \x89\xd0\x01\xf1V'
        b'\r\xcc7\xba\x7f91\xe2&\x14\xb5\xb6\x92\x0c&\xe3Q\xf9\x04\xfa~f\x80\xb4f@\x1d\xf2|\xb5\xdcF\x1e\xa0\x88a\x1a\xeche\xe4_\xc3\xc0\\\xdae\x10\xfe8\xb2^\x17\x03\x89(\x18\xdeD^|k\xfe?'
        b'%3\x8dCJ\x92\xd3\x9b*F\xa4\x9bE[\r\xf6/\xfd\x01\xde\x96\x18sb\xe0\x8e#\x99\xbcx\xdb\xcf\x8f\x90\xe8\xe2V\xd3\xd7\x12yhY\t\xff\x99`\xd5\xacA\xd4\xed\xdc\xb5G\x83\xf9\x91<\x9c&\xa7\x99\x1f'
        b'1\xc1y\xf9:&x\xe0\xf8\x14G\xce\x96.\x10\x02\x83s\n\xaf2\x13]\xd3\xbd]\x92u\xbb\x8d\rd\x18\x90$\x8e\xc5B\x0b\xc6\xca\x82}\x1f\xd4\xb7\x8b\xec\x9f\xe0\xb15I]\x1bT\xa7I\x05\xa7\xd1t\x1e\xe3'
        b'\x16\xafwG\xbc\xf2\'\xf2\x01\xab\x81X\xb8\xa8\xbd\x9f\xbb\xe2\xe2\x1d\xe0\xb9"\xa5\xb4\x9bO\xf2\xd7_\x0b\xad\x06\x86\xaffM\x8dkc\xc5\xd9\'\xe8\xf5f\x89]\xdb\xb6\x8fauv\xc5\xaf\xf3\xf7\xabk\x07\xf2\xfd\xb5'
        b'3\x0cr\x93M\xeaz\xa4"\x07&\xfc\xfbM\x01\xba\xe6\x9f\xbbNy\xec\x01\xa5\xc9zRa\xbe~\xb0\x92\x84\xbd\x9d\x10\xff\xd8K\xd0B\xe5)\xb4E\x9d\xa0q\x84Tc\xba6\xec\xe2D\xf6\x97v\x0b\xc2\xb09`'
        b'\xf2|\x97W\xadv;\x85\xf3)\x92\x9d\xae\xe6rQ\xfb\\x<\xee\xe7\xa2\x0b\xab\x93BH\x18\x0e\xf3\xde\x13\x19\xf1\x9bIz o\xd2\x99\xeb\x1a\xff\xdbz\x9f\x19<\xe1_\xb6p\xfb\x7f\x9c\x1e\xfe\x05\xb0\xabS#'
        b'a\xea\x17\xe7\xb7o9\xc5\xe7>.\xe4a\x95\xac\xacN\xbc\xbcq\xb8[N\x9d\x15\xaa\x9a_\xe9G\xb7\xe0\x18\xb6"\xb3WF\x99\xa8\x9a\x15\xf6\xd3\xe2\xe3\xa1\xab\xa5\xec\xf8\x0f6\xf87}T\xa9\xcf#91#S'
        b'\xc3B>\x0b]\r\xb1s\x81\xe7\xd3\xc0\xe6\xf8Jr\xee\x042\xaa\x0c.\t\xf3\xb6\x95q)\x9b1q5+\xaf\x95Ny\x14\x8b\xcc\xa2\xde}\xce\x0c\xf7`h\xd8\x04t\x14xT\xd8\xcbc \xe6\xd6\r\xb0d-'
        b'\xe9\xb9\xaf\xa0\xed\xfa\xe1st_\xd3\xe5\xb6"W\xdfx\xb77\xe6\x17(\xa3\xe4\x1b\xb9\xa1\xe3T\xd0\xf1\x1b\xf3\x9f\xa8\x11%\xdc\xf5R\xf0\x94&\xa0w\xcf\xb3$\xf1\xff\xfam\x89\xf5\xf0\xf9!\xedC3\xa3`\xadM'
        b'\x0eYI\xcfjl4\xcc\x97\x7f:.\xfd\x13\x84I\xd8\x8b\xbb\xf4Da#<\x84\xa8\xe0\xdf\xbcT\xc7n\xb3*\x00\x01\xd7\t\x1el\xe2\xd9\xa9\x99\xfe\xd6\xe2\xfe1\x16F\xe7E\xa1~0`d\xc0\xcf\x11\x8c\x1a\xec'
        b'W\x13S8N\xb8\xd2\xc8\xd9\xf6\xd0UM\xa8\xb4\x98|\xdd\x15\xbb\x16R\xa4\x03\x82\\+;s\xa7\rz\xb3s2+\xdb<\x92z#\x1b\xa6n\x80\xbcA\x95I|=\xa3\x00\x95\x99\xad\x93*$"\xd5\xe0l\x80'
        b"$\xc0\xc1\xd3A_\xf6\xf7\x98\x8a\xff,\x05]|r\xb1K\xfe\x97\xe86\x17\xb7\x16\xef\xc3\x86\xa9\x96\xfd\x85\x854\xe0Vf\x8b\xc7u'\x99\xf7]o\x0b\x8bl\xfe\xb8[\xb3\xcfE\xdd\x13\x1f_\x99E\x87\x16\xd4\xca"
        b'\x91m\xdf:\x08C?\xe3\xc7\xb7\xce\x12\x05dB]K\x16bSj\xb7\xb2\xe5A\xec\x03,\xee\xf9m#rT\xa4\x90\xef\xa93\x00\xd2g\xa5\xe3\x91]V{\x19]\xe6\x84\xd7\n\xb6\x06\x98\xbd\x0c\xcbC\x8es\xaf'
        b'\xa7@ql\x19L\x0ex\xeel\x13\x8c\xa1d$\xbc\xcd\x0c\xae\xe5f\x9d\xb9 t\xae\xb1\x8dt*?Fq\xd0\x16"\xb1COR2\xaa\xb3f\xd7}1\x16\xc7H+p\x1d\xf1\xba\xd5\xfa(^\xff\xe1\'$\x91'
        b'\xe9\xacC\x1c$\x9a\xa3!:N\xc3\xc1-\xc3KsM\xdc\xe14\xa7\xa1\xe3\x03=\x06V\xe4\x81\x17\x97^P\xe8]\xd3\x07P\xde\x7fL\x99\xad\x97\xfa\x80\xa0\xd3\xdf\xa9\xdc\xe7D\xa0>\xe2\xc0\xf4>\xfe\xe2P\x08\xa9'
        b':\x9c\x1b\x08\xe6\xf6^S\xf2\xfc\\os\x15\xf8\xc5\x12\xc5$\xdf\xf4JA\xbb\xd7"]DD(qdXar\x97\xfe\xee\xc3\xf3\xfc\xa36\xe5\rJ\x07!\xdb`\x9dI\x81I\xfe\xed\x90\x04\xab\\\x03\x7f6\x12'
        b"'\x01Re\x9e\x0ft\xaa\x05\x0c\xfaH\xa2\x9d\xed\xd2\xb8\x1c\x92\x17]\xe0\xcd\xf7^\x8a\xbb\x11\x9c\xbc\xfb\x82o\x16\x7f\xd7H\xf4!\xbc\x10\xd3\xeb\xa5-\x88#\x9a\xd3\xfb>\xc6w\x1d\x92\xdc\xa5\x93F?\xf6'Q\x1e"
        b"\x0f\xe0\xd5\xa5\x1e\xf2\xdf\xc0\xd8\xe0g\xae\xbbjD\x8b\x83\x02mI\xdel\x19'w\x01E\x95\x803\xbb\xe3o9\x19\x03@4\x0e!\xf6\xec\x93\x7f+\xbd\x0b+\xfdb\xbeXG\xef\xb0\xd5\xe3\x7f\xb9#\x13\x1d^L"
        b'\x8d\x9b\xa0\x86!T\x93`=\xe4\xde\x0e\xcaTv_]bL\xed:\xcb\x86\xb4L\xc5\x10\x85~\x91`\x03\xad\xc7\xe1X\x89\xc1@\x16\x96\x8bS\x8e\xaeH\x17\xa4\xfb\x1a\xccJ\x9f\xeb\xac\x85\x1f\xb6"36J\xe8\x01'
        b'\x08\xe6\x98\x9csk*K\xe0\xbc\xe8\xe5\xfdFM\xea\x12\xa5\xda\xee\xd7\xe0N>g$t\xe6z\xb0\xcbL+xg\\|k\xb8\xa9%\xc9\xe6\x8aDw\x8e?\xfc\xf2\x0e\xd33\xc1\xff\x89\xf7\xd4C\x06\xd5\xad\xab\x8d'
        b'94\x03\xf2x:\xe4$\xe5\xeb\x15j:2\xb5\x10\xd1\xc0\xad\x92Et\x9fs\xce\xcb\xd5\x04\x86*\xbcW??\xa5\xff\xb0\x1d^\x9c\xb1a\x1f\x05\x88z[4\x18\xf5\xa2\xfa\x1d\x9a\xf1\x9c\xc3\xe6\xcd\xb4\xc61S\xbb'
        b'!I\x98\xdfCdF\xe9\xd3\x01\x17\x81\x957\xfa\xcb\xc5+\xa5\xb6\xf6\xcb!ZU\xea\x13\xf9@\xb8\x04p\x83tn\x0f\xa5\xd4\x9f\x82\xce\xfdH\x80\xa6\x19pS\xb8\xa6\xb0K\t\x18\xd5\xc2\xda\xd7a\x8a\x9bB<='
        b'\xf2E\xcc~\xb4R\x18\xaf\x85.\x16\x1b\x85\x1c\xd6\xee\x16h\xf6\xb6;=\r\x0f\x03+\x86\x05\x8b\x86\x9f\x00\x84Yj\xe9\xd06\xa6\x9c\xaa!\xe7\xdby\xeb\n\x018\xcc\x13O\x07nrH\xb5\x06_\xb8\x01%Y\xfa'
        b'"v\x88\x14M\x0eAO\xb3P\xfb=n\xb5nI\xf8m\x8e5\xa5\'\x15\xbe15\xbf]A|\xf2+X\xdb\x9aO*\xfc\x05\xbe\xea\xf7\x05^\xc7o\xb8\xcb\xc1dWD;\xa7B\xaa\xffp\xdc\xb2\xb7/\xe8q'
        b'\xaa\x87\x89/8\x07"\xf3\xf4\xbf1\xe3\xe5\x9c\xd1U\xae\x18\xd6\xe1\xb6=\xd1J4V\xe3Pl \xde\xeb&\x9c\x13\xad\xf9F\xd5T\xe1\x9a2\xe1\xd97\x12\xfbWE\xc3\x85Iq\xa63G\x0eq\xe9\xb3`d\xd7'
        b';\xb7c\x0e\x87\xd5g\xf1\xba\x01zI\xcd\xf1?]\xb1\x9f\xdfq_%9\x00\xbb\x84H@/D\xd7\xfd@\xfb\xae.\x88\xa1].\xb3l\x00/Z\x9a\xfc\x80\x8e\xf2&?~_|N\x8bdI)\x9aH\x9f3'
        b'\x8f\xf2\xe6\xcd1S\t\x1b\x86\xab\x01%\x15G\xdcS\x01W"D\xd3t\x84\xe0\x89+L\xb4O\x00$\x0c -\xc8\xf3\xf6\xf9k\xc7`\xaa\x11"\x1c\x15\xee5\x7f\xe9+k{nG\xba\xe0\xe9~\x8fX\x01\xaa\x89'
        b'R\xd9=<\xebJ\x8b\x84zz\x0f\x9a\x02\x17\xf7m\xfe\xf6\xca\xbf\xa2\x8d\xea]x\xa9\xf6\xd10x\xb3\x1b\xcb\x97gY!\xa8|\x10!\xedu,\x05j\xb7\xc0\x0f"|\x9a\x8e=\x06RKH6\x92\x13|Fz'
        b'\x0fVg\xe9_\xf9F\xbaU\x0b\xcd\xd6\xf0\xc0C\xbf9Lq\xc2\xcf\xa2\x90\xe2q\x1d"\x19\xf2-\n\x0c\x1eX_\x96\xb1d\xadik\xf5\xeco\xd2\xe9M\xd6G+\xad\x8c&|-\xedm1\xe9\xbd\xac\x9a\xc2\xf9'
        b's\xf9\xff\nB<\xc1I={\x8b\xbb\x1d\x1d4\xc6\xf6\x1a4"\x97\xa5\xad\xb8\xb5\x14\x16\x14\x8a\x86\xac\xdd\xf8\xf1\x0f\xd7\xd5~\xe2\x95M0\xa0\x1f\x0f\x84(\x01\xd0\xad\xbdm\xa3\x03\xaa\xa9\xd4\x12\xfcV\xcd\x81w\xc8'
        b'kR\xcb\xec#\xf0\x1dZ\x94\nA/N/\x7f!E\x05G\xf5\x85u\r\xd4\xf6\x8c%\x8d\xec\xc6fE\x07\x8c\xee\x13\xdc\x9e\xe5Nz\t]G\x99\x80U8\nR"\xb0\xb9\x1c\xd7\x9b\x86X[\xd7E\xf1T\x08'
        b'\x96o\xb4s\xf9\x9b?\xe949\x0f\xc0&\xdd*\xe2\xc5@7\xb0B\x0b=\x9c\x0cK\xaa\xd8Um?\xb6\x8f\xe0\xd6\xe6\xff\xf74D\'\xa0"\xe5m\xde;\x12=\x90\xbc\x16\xfb\xbe\xff~\xcbG\xc7\x01{t\xcb-'
        b'}\xeb\x16\xa5Q\xe5\\\x01Q\x12s$\xe8\x14GG\x8e\xfddd\xb7\x92\x8en\xbe\xa0/\x9d\xf0\x91\xd4\\\xd9\x1e\xf5\xf3A\xf8\xfe\xd3\x9d(`ob\x8b\x1a\xea\xf7$\x8er\x8dc\xe1S\x0c\xa0\xb8\x83m\x90~\xe4'
        b'\xa1\x004\x1c\x1a\xd5\x04\xe8.\x95\x06\xff\x95CYN\xf2\xd4\xb2\x81\xa3\xd11\x00p1\x0e\x03j\x8f\xaf\xc3\rd\x945gLJ\xe1\xafk4\x90\xb1_\x91\xbf_\xc4\xaf\x92\xd2E4@\xbe\x99\x17\x12\x94\x03\xca\xf1'
        b',u\xa2tT@\\\xcc\x8ct\x89\x84\xa7\xe9\x1a\tK\xf1\xb9tO\x98Q.\xa4Bh\x06\x06u\xe4Jq3m\xc8q\xdb|\xd2x\x17\x1b\xc3_\xde\xc7\x9c\xe0\x0e\xba@[.\xa1\x9d\x9ff\x86\xbe\xd1h\x8b\xd9'
        b'\xd1D\xa8\x00H\xc8\xd2\xae\x12p\xd9\xb5\xed\xbf}\xd6\x1dS}\x06\xe0\xff\xc4\x94\xdc\xf7$mI\xb9\xc4\x15\x04=:R\xe9\xf9\xd8\xa8\x91\x01\xe2.\xb2\xff,,\x0cR=\xfa\xfeE\x93\x85\x01wh\x82\n\x9c\xde.'
        b'\xffS\xc3\x84\x12Y\xf6m\xb3!e\xfb\xda\x82\x81z\xefEf\xeaG\x8a\xe5`>\x1d\xc94\xc8\x84\xe3\xfb\x8f0MQ\xf0Pm\xc3\xd0\xb8\x15\xb3\xc1\x93\x02b\xd0\x82\xff\x99!>\xfb,\xa1\n\xe6nBm\xd0\x08'
        b'\x81Z\xf3\x17HEdN\xdb\xf5\xbcwB\xd0\x9af\xb8\xe7\x91\x9dw\xba\xc1\xf8^mE\xd5g\xb8\x8c\x07\xe8\xe6\xdb\xbf\x94\x15\xe5\x01\xbe\xf7\x8a\xdc\xae\xc8W\xd2\xe5\xd0YP_bw\x11w6\xaf\xd6\r\xe3\xfc\x05'
        b'\x89\x1f\x12w\xdcJ\x0c\xb9#\xc0\xcbJ\x01}|K\x91\xed;\xa6Gqa_#\xa6th\xa4\xef\xf3P\xd1\x0f\'\x04\tS\x8d\xf5B\xabjn\xab\xf3\x97\x9f\r\xadk\xf9S"\x83H\xf2\x8d-\xd5s\xf4\xa1\xf6'
        b'\xbe\x01\xdfZj\x16\x8c\x90\xb0\x92\xd3+\xcd\xd0n\x15\xbbCe\x8b\x99\xbd\x10\xd9\x00\xa8q\x18Z\xd8\xbd}\xe0C\xb0\x96\x84y\xf1\xa7\x03\x92v\x8eQ\x05\xd4\x13\x1e\xef~\xd9\xad\x08??\xc2\x9fd<\xda\xd7\xe4\x94'
        b'L9\xe8\x19i\xb8\x1e\x9b)`\xe8){\x155\x97\x05\xd0\r\xb9\x1c\xc7*3\x9d\x13\xc9\xf0k\xf5vI\r\xeb\xd6]{1:\x98\xd5u\xe0.>\xf6)0\xf9X\xbbJ?A\xae\x93\xf0\xd4}+\xb3\x93)\x8b'
        b'\xf7\xcf\x9bU\xaa\xfe.\x9c\n\xc1*En\x84[\xeb9\x98\x99L\xe0\xa7[\x0e^\x1a\xdf\x11\x93\x0b\xef\xb8\xbfT1\xae\x97B[\xb8\x99\xd0\xe6\xdf\x9dJ\x10L\xc94<,\xd1\x057SBc\xaeS=\x91\xa4\xdd'
        b'\r4\xea\x18\x93\xbc\xe6a\xc7@M\xf3\x93n\xad\xda\xae\xac%*\xc2m9\xc0\xa2\x813,\x10\x00n\x1ef\xe6\x8cn+\xdd\xe8\xa3D\x96`P5<\xb3\xfa\x92\xd0\xae\x8d\x0b\xcdK\\W\x94\x02o+\x9d\xb9\x81'
        b'O\xeb\xe5\xca\xa2\x10\x95n.J\x08\x19\xb1K8\xe5Y\xb4+\xdbM\x0c\xe4qGb\x9d\xdc\xdd,:\x17\xcbJ2\xfe\xa4\xb2\xcf~6\xed\xc2u\xac\xb01\x80!D2\xa2\x02\x81\x84f\x81\xd0\r\xb5Q\n\xe6\x10'
        b'\x04k\x13\xc5\xcfsB\\\xe3\xa5\x9a~\x19\xfe\x0b\x80\x08UQ\xcd\x0fh"\xbc\xdf0\nO\xdb$\xb5Zi\x7f\x89l\xf7\xa9Z\xfaj\xab\xc1\x05\xe0\x9aYl\xee\xbc\xc1\x92i\xa2\xa9\x963y\xf3M\xa6o\x96\xf1'
        b'\x93\xddf!\xaf \xdfy\xe4\tu\x12\xf3<\xd9\xa8\xcd]\xf2\x8c\xafO\xc1\x81\xd5\xe3|\x07\x0b\x0b`\xf5\xda\xe6;~a\xe1\xff\x8c\xe0\xa9\xd4\x04\xb7|\xe36\xc4\x91\xc9\xe0\x8a\xcbR\x83Bi\xae\xf2-E\x82M'
        b'z\xfa\xc7\x98r\x0c>[\xe3s\xc1\xf6\xa7\xca\xa6+\xd2}\x19\xa9\xfdm\xb7\x87\xd55m\x11\xace\x81\xc2\x10\x8a\x8f\x14\x02\xc9+Dz\x95\x1715\xf2\x9a\x99U\x1d\x1a\xf5\xaf\xca<<\x81?\xbe\x0b\xffv&\x13'
        b'\x81M\x0b\xa4\xd0[\xa4.\xf70\xd7\x97H\xef"\xc8\x83$3\x00F\x8b\x8a%\rF\xc1\xa7\xa0\xc3\x18\xb5!?d\xb6\xed{s\xf21p\x86\xb7t\xaf\xe3!{b\r\xdb\x1a6\xbb\xa6\x86\x04?\xa7\xd6\xd1\x11\xb0'
        b'\xc1\xc6\x18\xa4\x160*\x80g\x85\x96\xbf\xb6\x86\xb2j\x02z\xe6\xd7\xd2\x0f\xb8zsuGw\xeb\xa0I\x07\tmH:\xd8S\xdbl\xa5\xacE2\xbb\x12A\xff(\xbc\xe8\x16\x8f\xe6\x1b\xa2\x1a\xa2\x10I\xb1\xb5\xa0\n'
        b'\xce\xabN..\x12\x94\x8d\tC\x9f\xe8\x89)\x88\xc5\xc3\x7fW\x86\xed_c7\xc2\xa4i\xe6o\xaf\x97\xf7A\xe0:\x17%C\x96\x8f\xe2\x13\xe8>\x81OL\xe3\xbeJ_\xf0K\xcb9\xc7U\xf7k5@\xe1\x98\xa0'
        b'\xa5\x19\xa7\x1fXY\x86?\xa1|\xba\xb4\x9d\x0b\xda)\x12t\xd81\x9a4\x03\x03\xcew$\xfe\xcf\x9d\xd4E\xe8z\x85\x1a\x17\x1a\x02"&\x17\x08\xb6c~\xa3\xca\x8d\x03\xf4![\t\x88?\xba\xb6)8\x98\x1d\xf7\x8d'
        b"\xd1O\xe2\x01$\xee\xdeq\x10]}\xa0p(\x0c\xee^\xfa\xb2\x8b\xf6\x86F\xeal\xd9|B'n#\xdd\x83Q\x13\xcd\x17\xb07#\xb7\xe3m\xdd%\x04\xea\xf8Pv\xb0D|\xc3\xb5\xc0\xe0\xc9` \x80\x0c\xaa\x8a"
        b'X\xcd%X\xda\xc4\xa3\x81"\xf0\x1a\xf9\xcb\xd0\xb6\xcb\xef\xf0 \xf6 \xf0\xd9\xf1l\xb7g\x14F\xb3\xb5\'\xc5\xcb\xb5\x07\x1c\x02\x95\xa5\xd4V\x91\n\xb2\xb7>\x9a\x04 N\xba\xf8CT\xf2f\x8b\xa4\x9d\xc4S\x95?'
        b'\x14*\xc9`\x11B\x88\x1a\xfd\xf9\x06+\xf1\xb8\x03\xd1NT\xaa\xd6&`{\xb31\xf3\x11\x05\x17\x85\\\xc5\xabuK:\xda\x94\xd1\x81\x83\xef\xd3\x01\x96\xc5"nP\x05s\x00\xb9P2\xb8]\xac\xb6\xd8\xff\x11l\xe4'
        b'\xb2\x12$\xeeg\xf7\xf8\xfe\xb4^\x93\n\xa8W\x93K\x0b\xc2\xc4\x18w\x94\x00\xf8\x92\x82\xa2J\x1b\xb7\xb0f\x00\xa8\x7f\xee\xbcv9\xfdh\xaf\xf6\xd0\x81\xde\xb8\xd6cr\xd9(t\xb1\xd1=\x15&\xc8e\xbc\x01K\xe6'
        b'\xb9\xa6\x98\xedH\x8fA\xcavn\xab\xa9\xbdc{\xe9\x1e\xcfi\x96;L\x07\xc4\xd71\xe1\x16\xe0\x83\x94\x83\xc2i\xca\xd0l\x99\xb9\x00e\xc8\xdc\xa2\xbc!\x85\xd6\xfa(\xa5[9PC\r\x1dSt\xa2T:\xddz'
        b'-\xfe\xbaoy!L<\xec\x85\xbb\xc1\xa3(6\xaf_B\xf0[\xf3#\xdf\xe1)\xf2\xb8U\x1e\x01\xb2GwT\xdau\x1eM\x07\x04x\xf5\x99\xa9\xc7\xba-ao\x08\x0b\x9d\x81\xbf\tDz\xab\xad2<\x93\xf3\xf8'
        b'7K\xcd\xaeh\xbf\x1d\xaa\xc8\x8bEZ(\xa2\x16\xba\xb9n\xb1\xeb\xc8\xa3\xb0\x93>\x8fe\xde\x1bH{\xec\xc9\x05{\x11\xb4\xe7C\x1d\xc0>\xa9\xb6\xd5\x84p\xd1\xe41\xc0B_s\xc9\x88\xa7"7\xb0F\xa4\xc8p'
        b'\x1bsH\x94\xe1\xcc\xa3\xbb\x01l\x11\x0ey\xcb\xbc\xed/\xe6\x16\x10R\xd1\x97Y\xefV\x06Ef\xc4\x1c\xf6\xbfVi/\xcd\x19\xcd2\x18\xb3+4\xb0.L\x16\x1b\xcaq<\xc0\xabM4{\xc8X\xf2\x81\xdc\x14 '
        b'\x15\xd5$\xcc\xab\xe8\xf9 \xc0\x87kSM\xdc\xde\x15F\xd1\x9f\xe1yY\xa3\x03U\x1bT\x13\xc7\xfc\xdf\xc8\xf5,\xf2x\xcbL\x0b\xe1#v\x80a\xf8\x95z\xf8\x01h\xeb/\x96]\xec\x0c0J\xb6f(yb\xba'
        b"N\x84B\xb7\xa3\xd6\x83Fj\xd7\xd7\xeb\xac\xf0\x9c\x89\x97\xf6\x1b\x13),e'\xfeC\xae\xa2\x98\x93\xfe-\xc1\xbe\xd3\xd3:6Q\xd4\xc4{\x18\xfc\x0e\xf5\x00 \xae\x96\x1eX\xcaiFo\xb9\xefD9\x08i\x96\xc1"
        b'\xe7u\xd2L\xe3\xd7;\xaf=\x05,)\x90\xd5L(\xea\xfa\r\x10\xc2+\x12\x07[\xcbP\xc8N\xdd\x99\xd0\x9fX\xdb\x07Q\xdb\x86\xec\xe1+@yt\x9f\xe96!\xd18\x87@I\x82\\]4\x11k~W\x9ff'
        b"\xa48'\xd8C\x9a*\xaf?\xef5\tF&\xb9\x88\xe9\xd7J\x1dNN\xd05\xfa%-\xb5D\x06\x13\xaa@C\x1b<\xd2\xea\xdeL\xa5\xcb\xa2\xc6}\x83\n#\xd9\xec\xe8\xfaf\xc5\x18\x98j\xc1\tT\x08\x9a')"
        b'+\x14?\x84\x16E\xb5]r\xff$q\x18\x97y\xa2\xfd\xa0\x7f\x8a\xcd\xa7\xbb\xc37\x80\xce\xb8\xe3am\x7f8s\xfe\x8czOni\x0fc\xce5\x15\xa0w1\x0ek\xc0\xe4wI\xb4\xf5D\xc6FF\xd0\xe6qd'
        b'\x03\x82\x0f(\xba\xabs\x01\x1f\xfd/\xad\xda\xbd\xbd\x01az\xb7e\x04\x8bm\xdfx\xac\x04\xf5\xe4\x01P\xdbe\xb9i\x07\xa3\tHzl\x8c\x7f\x8d\x08\xa7!\xf8\xb0\xcb\xf3c\x81\xdb:;\x98\xf7\xcfM\x9e$\xbc\xb2'
        b'\xe9Q1\xa1\x99\xafP\x1c{\xd5a3{R\xbdJ\xc5no\x96\xb9q\x80U\x16q\xd3\xb9"\xc3\xb1vL\xaa3\x00\xcb\x80\xf6_S\xa7\xabS\xca\xafb\xb0\xb2\x9e\xcd\x1f\xb5\x07J\xb0~\xc4\xde\xffc\x864\xd7'
        b'5)\xfd\r\xbc\x05F\x8e\\C\xb3\\\xbe\x1b\xf6R\x87\xfe(\xe0\x18(\x15\x7f\xd0\n\xbe\xaa\xd9l\xe6\xce\xd4t\x9e15\xe9\xdcO\xb9\xe4\x87M\x94+?\xd3\x8c\xd1\xb9\xc7\xa3\xbd\xedML{\xaa}f\xf0\xc7\xf9'
        b'\x81lW\x16\x8a7\xd8\xeaj<\xecn\xca\x9ayIF\xebK\x06EzL\xac\xd4\xe9\xc1\x1d\xf3}\x98\x9a=\xb9\xe6\x92\xa2\xabN\x88S\xc8\t\x8c$\xa9\x1bn\xdft\n\xa3\x9eG\xc1H\t\xdf\x00\xcb7\x16\x92\xd9'
        b'g\xb1\x9f\xf9\xb8\x1c\x95\x15\x9b\x14\x8a\x1b5\xce\xed\xdf\x06E\xd0\xa2\xa6\x04\xb9\xb66\xf5\x0c\xf6\xe0\xa5\xe5mf\xc4a\xeb\xa9U\x9df\xfd|\xfeg\xe9\xdb\xb4\x9d\xd2\xdd\x19\xe3\xccfTJth\xc4Qo\xd3[K'
        b'\xaal\x08\xa6\xcc\xc8p\xa9\x08\xd4[\x1e\xe9]1f\xe2TK#\x15\xe2\x15z\xa97_\xcfX\xfb\x82SO\xbf\x99\xa1\xd6\x11\xb8u!0P\xbd\xa4Y\xb1M9\xedq\xc9ts\x12O5\xfb\x98x\xb7XhH'
        b"\xcb)\x02F\xf6\xbb<\xd3\x94\xf8\xee\xf8TV\xa7\xd5\xae\xb7;\xa9E`\xb7 j8\xa5A\xaf\xd3j\x1d\x87\x04\xe7}\x1a2\x151\x9d\x04\xc3\xc4\xf7\x81'\x18\x9f\x95d\xa2\x95Jt\xc9>^/\x99\xaf\xce'\x00"
        b'\xf5\xf3=d\x92x?\x1e\xa7B\x0eQ\rZx\xfe\x9c\x91\xa8\x17\xb0@\x12\xfd\x85\xf8\xfa\x9e/\x97\x97_\x8dI\x8b\x0b\xf4\xe1m\xbc5\xb1w\xb9qzhyw-\x04\xd3\xa5\x16\x9d\xd5\xb1Rw\xf10|<\xda'
        b'\xbb\x82}7\x90\xf2\xfd\x14\xdbI\xf0k{\xb2\x07\xee\xa3\xf4Fq\xee \xb72\x92qS\xc9\xd4\xbdBs\xd8\xadnh\x00\x06SZ\xf2\x95\x0fZ\xdcYJ\x8e\xba\xf6\xe62\x0f\x0e\x80l\t]\x92\x9c\xc5kpA'
        b'\x9e0exkcz\x11\xec}3\xbd\x8d\xab3\x94\x0co\xa9NC\xe8X\xddD2\x8f\xb1K,\xd5\x1aP\xd0\xf0\xfc\x11\xf9\x19\x83\xa5\x05$dm\x81\xc9T-\xc6,&\xa8,\xa3\x96p2p\xc8r*i\x00'
        b'\xac\xa3)E\x0b6\xe3\xba\xf7\x9e\x17C\xa3\x8cSY\xb3\xf4\xcf \x12\x19\x99b\xa7\n\xf4\x8f\x04\x10D\x10X\x89\x99\xddV\xd8n\x06\xca\xe0\x89\xae>@\xa0\x80\xb6X\x0fGdyu\xc4V-\x98@\xe9\n\xb1\xb5'
        b'\xa3\x8b\x1b.\xe2~j\xe9W+\x8cKUg\xa1_\x91\xe0\xf2\xbb\xda\x95\xa0\xb8\xca\x92\xee\x86BN[\xa0a\xd97\xebxEp\x85\xdc\xa7\xbd\xe4jH\xc6T\xf2\xdb\x13\x0e\xcbEs:\xeb0\xa9}\x12\xd5m\x1c'
        b'\xd7\xf6R\xbds\xd6\xe8B\x7f\xe5X9\xc9\\\xe1l:\xe7U\x0c\x895\xc5\xc4\x14\xc9\xae\xe2\xa9\x07\xa8\x93\x188\xb8#\x08\xdb,\x9f\x9fr<\x1a\xf8\x87\x95dd\xa1x>^\xb7w\xa1\xac\xf4yq_\x1aC\x12'
        b'\xa8r\x91\x9b\xa3\xbd\xc7b\x8f;y\xf2\x87\xcf\xbdq\xfdV\x1dU\x80\xa0B\xe2+\x88/\xd3\x95o\xf9H\xfc4\xfav\xad \x02\x99\x8e\xabV\xcc\x8a\xf1\xeeN\x86y\xebH\xa0g\xa3\\\xdf1%LY\xc0\xeb\x89'
        b'5s\x83c\xe8\x1f\x91\r\xa4.\xd1e?\x17\xefQ\x96V\x9752\xb0\x11\x8e\xc6\xe2[\xb5\xa8O\x7f\xceY\xa6X\xd4w\\\xa6OI1\x95\x7fC\x039\xc0.\xee6\x12\x1fw\xc2\x98\xb2\xdd<\xa9\xaa\x97\x12\x1d'
        b'\x05\x8c\xf8\x01\xf6@\xb6\xc4d\xaa\xc5\x00\xf9!U\xbc"fZ\xf3,NV\xd3\x18!\x11\xa2\xaau\xa1\xca\xd9%7H,\x82\x8eh \xaeA\xa7\xb6\xc7\xaa\x1e\xdb\x03v\xde>\xaf\xd2\xfe\xce\xe9\x01\x00\x00\x00N)'
        b'\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x15<f'
        b'rozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x08\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
