
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']

def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    ...


class SWIFTParserError(Exception):
    """SWIFT parser returned an error."""
    ...



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x02X\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadedsd.\x00\x00PYARMOR\x00\x00\x03\x08\x00U\r\r'
        b'\n\t4\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00$.\x00\x00\x00\x00\x00\x00\x8a*\xbe\xc7\xf7\x19\x80\xf0\xf3i\xb2Dv\xceM\x06\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2o>\x8e\xc4\xaa=<\xa9\xb1\x89&^\xd5=O\xa7\xcb\xd6W\x96\x9b\xca\t"\x83f\x82y\xfas\xfb\x13g\xea\xa2\xc1P\xb0\xd3\xb8\x15\t5\x81\x92\xe7j\xef\x91\x87\xc0)X'
        b'#\xd8\x8e\xdcl\xd2\xc8#\xf8\x0f\x9c`\xf3w\xbd\xc4}\xdf\x89\x07\x9b\x87\x12\xd7\xa20\xe1\xe1\xa8\xf4\xc1\x1e[?\xb7d^C\xa1\xa4\xbc\x7f\x16,\xbe\xbcpmij\xd6\xe2\xcehdg\x8a\x934\xd5\x9et\xdf\xd8'
        b'\xee\x01\x15\xcf?\x10\xc2\x18iW\xcb4v\xdd\r\x19\xb7\xfbKM\xa5\x94\xab\xbc[\xc1;z\xeat\xe3\x14\xff\xbah\xbe\xe1%\xd5~\tf!\xef>\x89\xb2<.\xa7cG\xfa\xed.\x88\xe68\xb1H\x06\x17:\xc1'
        b'\x8d\xa6\xfb\xf3\xfc\xbf\xfbD\xe5\x0cTMA\x18_(\x08[ \xcc$\x1af}\x91\xa1\x8b\xf1tu][F\xeb\x89\x82\x8d\x9f\x00j\x12`\xa8\xf5\xb50\x80[\xdc\x11\x87\xd1*{d4^\xa9\xfdi\xf7\xe90|'
        b'\xcc)\xce5\x9d\'\xde\x8f0bv\x8e\xafR\xf5p*\xb8&\x13\xc5\xec\xc0\xbc\x18\x7f\xd0\rO\x0b{\xea\xb0\x17\xe9\xa5\xae\'\x95\xce\xeeA\xe0"\x9c\xb6Cq\nL\xa7\xa7F9\xf7\x7f\xf67\xa0\xfe\xa0\x84h\x02'
        b'\x05Y\x01\xfd"Lz\n\x86\xe8\xe0\xa3\x05\x96\xec\xb4H:\x88=E\xda\xdeF\xe2a\xce\x03\xa8\xeb\x8a\x0c\xbe\xf6\xcd\x7f\xa2\xfam\xb5\xf5\x88cQ\xe1\r\xb7\x89\x18G"\xe9\xf8\x1a\xb7\x9ah7U;\xab\xfc\xc0\xb9'
        b'\xfd\xd3N}\xb1\x13u\xf4!\xb3[O\xa26\x8b\xab\xaf\x8b\x05c\x18w"\xf5\t6\xadh-\x1eF\xe4\xe1\xb1b|Sh\xe3.K\xa6\xd4\xcd\xee\xfcGB\x11\x97>\xe2\xffT\x1f1\x06Z\xbd]\x17K#\xc6'
        b'\x0e\x99\xad\xdf\xd94$yv\x85\x02\xa6\\\xe9\x0e\x8c\xf6\r\xa1A(\xd9\xe2\xc4\x956\xe5\xc4Oz\x18\x17\xd50?\xc1^\x17\xdb\xf3\xc0\x8d\x8d\xfd\xcf\t\xbcd/\xbdB\x8d\x12\x0e\xfc{D\xadT\xfd\xe5?C\xa4'
        b"\xc1\r\xa6\xa2}\xde\x8a\xe3\xf3\x14\xa4')\x12\xce/^\x9b\xee\xa2\n\xa4\x1a\x85\x93\xa0\x81%!\xa3\xb6\x84\x05\xa6C\x81B\x15\x9c\x9fK\xcdZ\x03\x1e\xe1\xc6\x02\x8c#\xb5TN\xb1\xa5\xe2\xa3\xe8\x8e\x00\xfd%\x1bK"
        b'\xfc\x98\x85\xe4a\xe0"4p\xa7O#Z\x86\x1e\x96]!0Rr\r\x80\xaf\xb6\xba\xccJ\x8d\x05\t\xab\xd8\x81Z\'#\xf5\x7f\x7f\xf4\xde\xc1\xd7\xfb\xce\xf3I\x7f\x0fq\xb1\xaf\x16\x10y\xb3\x9dF\x03\x9e\xc0}\xec'
        b'\xbb\x1d\xd7\x84\xaa\x1d|\x96\x84\x95y\x92\xe0\n}\xd3\xe6-\xbe\xbd\xba,T\x1eK\x84\xe6\x8a\x15\x92\xaf\x9b\xfc\x14\x89\x80\x84\xf2\x87\xd4\xe0T\xe881\r\xe5z\x7f\x9d\x03\xfb\xe0\xd3"\x9c.FI\x17\xb5%\xdf\x03'
        b'4\x15\xee\x12\xfa\xa1(\x80\x8cd\xa6\xd3j\x14\xbe\xc8\xa8(zNp`\x99\xf1\xd9;\x8e\xb4]\xd8\x84\x82\xe8\xaa\xeb_\xfd\x9bK\x8c\x11g\xe2}\xdb\x10\x89z\xeb\xda\x8e\x17{c\t\xd6D|\xbfJ\xc0\xc7\xce\x1e'
        b'\xccU\xa3\xf3=R\xa4Xh\x91\xba+\xb3\x14O\xb8\xe3j#\xbe\xdd\xb0\xd5\xe6\x15\xd9\xef\x05\xa0=\xd8&\x86\xac\xe7\x05\x80x\x9fN\xbc\xb8PA\x02\x95\x93X\x8c\xea\xaeE\xf6\x99\xa5\xbc\xe8\x8e~\xdfe\xca\xe15'
        b'\x1d\xa6HlyP\x0e\x07\xacob\xa9P\xe9\x0c\xaa\x16e\x892\x7f\t\xde<QT\rC\xcb~\xa7;~5\x0c\x85\x8d\x14\xda\xc7\x8a\xeeO\xbfh\xa6\xbb{\xb0\x02\x82b\x04\x1d,\xa6\x9f\xa8\xf4\x13\x12\x0fs\x06'
        b'rW%\x15\x82\xbd4\xd7c\xd0T\xba\xdb\x00\xde\xf5\xd7\xcd\x9b\xdeU5\xf8\x93\xcc%\x95\x9b\xcd\xce\x06.E\xf8\xdf\xad"\xf7\xe2p\xd0\xbe\xe3\xf0e^\xfb:\x8c\x15\xce0X\xe5\x115s\xe8\x99\xd0\x0b0G-'
        b'S\x81J@\xd1\x05j\x88\xcf\xb1\xcb\xf3\xab\xfc=`\xd8\xe3\xc8qU\x98\x8f\xcd|$\xc4\x8d\xf1\xb9?H\x8d(l\x1d\x97O\x97\xbczZ\xc6\xbc6;\x94\xd3x*\x17\xd92B\xe4\xa4aCB\x88?\x0b\xe7\xf0'
        b'\xcc\xc7\x08n\xbc\xf0\x1fx\xc8\xf8\xc64\xady!\x06:\xe3\xc3\xa1`[Ag %\xf7\x1b\xcc\xe0;*)\xb6\xca\xc2\xb17u\xe7\xd1\xb0E\xe4\x13K\xb3}\xb7bL\x92\x03\xc3L~d\xabT#\xaf\xa6\x01\x82'
        b'i\x97\xdf\xd9\xf2\xa2\xc0\xf0q\x8a,\x1b\x1d\x91hK*\xec\\\x9e\x93\xb7zB\x17F\xb09\xfd\xa5YY8\xfd\x83B<W;\xff\xfe\x94\x03\xb5\xba#\xbb\xa1\xa1>\xdff\x12\xda-\xb9>\xbb\'a\xa0;"g'
        b'\x03;-1\xb79\xe4\x8c\x9a\xa9\xf1\xc4\x1e\x13\xa6E|\xad\xa7X\xda\xa6\xdb\x00\x05y\xdb\x90\x89w\xef\x19\x88}\xf1\x19p\xb3\xd3\xacU\x1c\x7fL\x94\x04\x96\xa2\xcb3G\xde\x1af\xaf\xf3t\xb5\xe7\x15\x97\xb3\x00\x01'
        b'V(^\xf9\xb6\x91\xc6!\x1d\x814\xff\xd6\xf6w\x9cS\xcd#bz\x0c\xdc\x9aC\x1c\xafn][\xe3iu\x1a\xfe\x8fu\xed\x19\x08\xed\xb7\xea\x9f\xa6\xe8\x871\xf8\x9a\x19\x8a\xe3\xf9J\x94a\x01\x9f\x8a\x8d\xc3\x08F'
        b'_\xf1(\x9f\x07\xbe\x841*F\x1a\x85\xad\xbe\xcd4HE\x8f\xc9Kh\xa2\xe7\xa5=R\x02\x97\xce\x97/\xec\xd6\xaeCFU\x19\x9a^\xc8B\x11\xb3\x1a\xcd\x8a\xa1k\xaaG\xc3\xed/\xad\x1b\\.\x93\xcf\xd3\xec '
        b"\xbfM\xb5\xa1\x03}s\x02\x85\xedY\xf5\x98\xe1f\xf7\x1b3\x13~\xe5\xe4\xa8\x8a\xbeR(93\x86gH\xf0\xa4\xee\xa9\xb2\x87P+w'?Qe\xe4\x13\x12\x8ck\xb13\xa6\x01\xfa\x85\x1b`\n\xd94\x9b\x80\xab"
        b'\xd3\x98\xda%\x90\xcb\x89\x0eaKQ\xcd\xbf\xe1\xec\xbc\xf8_o\x99=T\x05\xa2\xac"]\xa3\x93\x82\x83\xeeJ\xc4\xf14\xaa\xf3\xddd\xb3\xaabw\xad2\x8e\xea!\x87\xeb\x9c{\xc6.\xa4\xd5\\"\xcc\x9c\x07?\x93'
        b'\x0b)\xb7\x93\x07\xc7}M\x19\xcb~\x9f\x7f\xe5\x9e\x9e-\xe2\x814\xfd}w\x14\x8c\xe7T\x8c\x92\xc2\x803\x19\xed\xc0\xba\xda\xe8K\xc7\xa9<\xaeV\x10\xa6z\xf5\x0f\n\x9d4"\xdd\xa4\xd0\xecQ\xbd\x8f\xc5:\xedf'
        b'4/)\xe6\xefh\xb8\xe8\xeeT\x82]x\xa6\xa7\xad\x93\'_\x10?\xbbg^4"\x11\x8f~M\x9e\x17C\xc7\xd7\x9a\x02\xb8\xd1_\xfe\xfdg\xce\xf3\x948\x85\x1205\xeb\x8b\x15\x9c\xdae\xbe\x06\xea\xd4|\xa7\xc7'
        b'3i\xa6\x0bE\xcf\x1d\x9eR\x9c\xaa\x16\xca\xdaH\xf6<\x04!*h\xb0\x8a\x19z\xfacI\n\xb6\x946@H\x16\xf4u\xeaQV>q\x8d\xd3/\xa9\xce[\xf2\xf0\x01\xc8\xbc\xf6\xcf\xfa\xa9m\xa4\n\x02Kt\x92'
        b'\x92\x7f\xef\xbf\xd6N9\xe0\x89\x07\xb08\x16~\xafQ\x81`\xbf}V\x86?\x18\xac\xd1\xca\x03\x14gs]=\x1c\x8e\xb6\x07\x0e\x8c\xd7=\x1b\xaf\xfc\xc3\xf7\xbbh\x00 \x13\xca.M<R\x08Y@\x8f\x8b\x01\xce\x9a'
        b'd\xb9:9\x02z\x94R1\xd1\x15\xa6\x08J|\xe6\x7f\xc1[\xf7o\\\x92\xe04\xc8\xf5\xc2\xc2[\xfc5\xda\xe9\x10c.\x81\x7f<\xef(\x0c\xd0g\xed\x01(l\x90\x1e\xdam\xbb$\xa5\xe6\xce\xcb\x1d\x8d\x91\xcd\x8c'
        b'\xba\x86\xb7\x80\xe1J\xba\xfb\xccox\xf6\x1e\x0b\xbd<M\x00\xf0\x19\xf3\xec\xa5\x10J>\x8b\xa0E2\x89\xeeb\xb6\x10m4\xa3t\xfb\x88\x86\x11u\xc4\xbf(\xeegI%m;\x0bj(\xe06v\x11%1s\x07'
        b'\xca|\x94\xb3\xcd\x8a\xb6\x80\xbdv\xed\xffH\x9btJ\xa9\x8d\xde\xferT\xaf,3\xbd\x88\xbc\xa0\xa4\x9b~\xf3\x9d\xdc\x85\xe2\x1d|\xd3\x1dBjK\xef\x90s\xb2\x81\xf04\xa7/\x7f\x83\x81\xf3\xd5\x9aF\x9e\x81W\xfc'
        b'\x18\xe7=\xd1\x86\x01\x8aj>\xec\xf9\x8b\xa9\xeb\xe2s\xc3\xde2\xad\xa0\xe9\x97\xf8\x81\xca\xfb}do\xa6\x08\x9cX\xeeM\x03&7}B\xf9q\x98ess\x9e\xe8w,\x1elx\x1d\x0b\xac\x848\xd9|(\xa5\x02'
        b'd\xb9\xab\xa8\xb5\xd6K\xf1\xf8\x96\x10\r\x0b\x89,\xb3\xd0\x02#\x92<\x1ef\x82%G\x88\x8d\x827H\xd2\x8b\x01\xef\x90\x84\x050-\x05\x8c\xfc\xc7\x89\\\xedO\xca{\xc4\x07\x03\xaf\xf3\xb4\x83\x18T\xa5\xeb\\\x8a\x17'
        b"\xd3\x04<\x03\x936M\x9f'\xfa\x84\xcb\x0cx\xf4\xb8\xe3\xb7\xf7\x9c\xe6i\xb4\x04\xf1\xc2q\xeeCD\xb9RP\xeb|Kp);\x08\x9e3G\\\x12G\x98c\xb7!Y\xa3h\xf68m\xb0\xae\x85\xb4\xbd\xc3\xc4D"
        b"\x84nc\x08\xb9\x88O\xfc;\xef\x1d\rW\x80\x85\xf3\x1dK\xfcMn\x80\xbd3\xe5\x91u\x0f?E\x05\x1f7\xc9Qn\x13\x86\x7f\xf8\xfe]_CK\xfc79\xb4\xffz!P\xa1\x02V'\x9cqb\xbf\x99\xb0E"
        b'\x12,\xd3\x1ac9\xa1\xf2Q\xefn}\x03Vv\x970r\x8d\xa3\xf4&\xff\x18\xe5\xe7\xbd\xee*P[`.\x96\x13\xe4.2\x8a\xfb\xcaDW\xb0\x1a~!\xc9{\x9c\xe8\xde\x9e\r1\xe7\xfa\xc0Q\xea\xed\x8eM\xc8'
        b"1\xc7'\x9b\x92.\xc8\xd2\xd5j\xf8\x14\xad<f\xe2<\x04\xaf\xc8O\x07\xce,\x15\x97\xc7k\xc12gC\x84\x93nP\xb7:\xf41r\xaf>\xb7\x1a'OX\xa83\xb27]\xac\xedh\x92\xb1!\xf5\xc8\xd4w\x84"
        b'\xee\xa1\x13\xf2\x06\x85 \xe5F\xa0\xbc\xfe\xc0\xa9\xdef\xe3\xce\xddB^\x0e\xe7qw\xce,\x05(\x889\x94!\xa0Z\x9d\xfb\x87\xee\xb9\x03l9_\xcd\x03I\xe1=\xe2\xe7\xc8!\xf7Vt\xba\xa3\xdc\xd3V\n\x99\x8e'
        b'l\x0fo\xda(\x8d\xad\x9a\x97\xc7\xdca\xe6(\x1b:\xed\x1e6\x12\xb6\x08\xc6\xa1Y!\xbb\x87\xf55\xf5\xe0\xb6\xf3\x11+iw\x10\xb6\x9b\xa33O.v\xed\xbf|2VCX\x90<k\x0e\xfbm^\xc5\x00^\xc9'
        b'\xc0Dl\x15\xbe\x97\x13\x19\n\xc3\xa8\x11\xbdf\x9bP\x9b\t\xe9S\xef2o\x03\x15w\xdfsQF\xf5~\xf1\x1d:"\xfe\xce\x1e\x14\x00\x1a\x92\xde48\x88\x14/Y\xf2\r\xeco\x18!_W\xd1&\xd0\x8f\x1b^'
        b'g\x9f\x06\x1d\x14\xa2\x88s)\xd0"Va\xd5\x80\xf3\xa5\x9c\xf1#\xd0[U7\xdb\x1c\xf5\x8b\xbf\xf7\xb9\xe29\xb8\xc3\x0b~\x7f\xd0\xff\x7f\x9ap{\xd4\xd2\xdf;\'\xa9\x9b\x992;\xf2%z8\x01\x90\x13\xad?\x15'
        b'\xc8.X)\x8f\x84@C\xb4t\x7f\xffus\x04}\x9e\xb2"2x\xf2*\xc3\xb3\x0f\x93\xe1\xb2k\xa5\xcfki\xf4\xb8\xe8\xc4\x95:\x16g\xb8\xb1Ve\x00\xf9l\x9e\xb9\x93\xa5\xbe\x99C\x1c\x8e\x14\x9e|N\xe3\x8d'
        b'I!\xd6\xfe3\xb9\x9d\x8d+\xa6\x00\xa3\xb3\x10Q\x10\xd9f\n\xee5C\x87\xa0\\\x15N\x05w{\xd6\x85\t:5\xee#\xfa\xb8}\x003\x8do\xfd\x1cm|\xd1"\xd7\x15\x81\xb3\xd6\xbfi\x0b[\x95\xf6%\x06r'
        b'\xe2\x1e\x11\xcf\x12;Oj\xe7\xcb\xbf+\xe9\xd4z\x05_u\x16\xbd\tz+\x17\xb0\x1a\xb5L\x8a\xc4\xea#\xc2\xfa\xde\xf5{\xc1\xf3\x02\xde\x19\x8b7h`\xdd\x01\x1df!\xe4\xa4@!\xc6\xdd]\xc3$\xd6F\xe6F'
        b'D\x94iz\x92\xe7\xabZ\xd1N\x93\xf8\x13K\x16@\x04,V\xe3\x92[\x08\xb1\x96x\x02\r\x84\x9b\xe5\xc7\xa7\xd7\x18\x8c\x18Y\xe8P\x05J\x82\xc3\xecG\x97\xe0\xf0;\t\xf7m\xee\xd0\x86j\xa1>t\xb4\xc5e\x8f'
        b'c\xb8\xe94\x036\xa5\xdb\xc8\xa2\x81\x92E&\xa3xG9\xb9\xd6\xa1}\x8f\xb9\x7f\x1c\x0b\x97\rB \r!V\xea\xadX\xb1y\x07.s\x1a\x089D~E\xedN\x18\xee"\xd6S!7\xbd\x8f\xa9\x97N2\xd7'
        b'\xf4&\xado\xd1\x7f\xda\xcf\xee/\x8a\xe6\xa5\xe5\x04\xa0\xbcahdg\xbf\x94\xc8\x8bH\xe8`Sh\xaaS\x83\xa9\xd6@\t\x9cm(\\h\xb0\xc9\xc5\x8d\xd5/\xc4\xe2\x10\xc6\x8e\x98_~O\xa1\xbc!\x01\x9c\xa1b'
        b"\x9d\xdc\xb0\xc39l\xb7\xa9\xd7t\xf5\xadV\xe9\xda\xcfK\xa7\xf4\x9eR\xa5\xfa\xa3\xe9\x13}zN\x02\x91P'\x98\x9ddJ\x98\n\xc8$\x87\xdf4@\x10`\xb6\xa3\x05\xb1\xdf\x9b\x87u>B\x1a#\xabqb\x0f\xe3"
        b':\x02e\x1b\xf6\x87\x8a1\x01K\xcd#q\x11\xf7\xa7\xdcrDv\xf9\x17F\xbf\xc5\xaaU\xca\x8f@\xc3(\xf1\x9d^\xa2$\xaf\x11>t\x92\x90Y\xe0\xd5\x9e\x9c\xfc\x97\xb0\x84,\xef \xf5e\x81\xc4&\x8a\xa7$~'
        b'\x02lJ)\xf0K\x88\xbf\xf1\x9ei\xd1_\xd6\xb1Q\x04b\xc0\xe3"\xf52\x82\xa7\xf6/\x9e\xba\x04{X\xd07\xfe\xf3;\xad\x1eh\x05\x97J\xda\xc2&\xe8\x0en\x9cS\xf4] i\x0c\x7f\x11\x07\x923\x10\xd5I'
        b'~({\xc3\n\x19\xc7>\xb4 \x97\x053\x87\xb3}\xa7\x1e/\x19\xa9\x0c\xfa\xd5\x02\xe5\x9d\x11\x86z\xac\xa7\x97\x8f=\xfe\x1e\xee)G\xb0<Q\x8d\xb7\r\xfd\x83\xe2A\x9aQXkhZ\xd6\xcd\x94/\x03\xf4*:'
        b'\xf0j\t\x91\x83\xdd\x1af~\xcb\xd3\xac\x14x\xc7j%\x99\xfd6\x921\x7f\\\xffx\x96\xf6=uy\xd2Fn\x8ca:\x0e;\xbd\xb2\xff\xa3+\x12\x15M\xf5h\x95]o\xb8|k\xbbk\x9b|\xcbA\xde\xe9\x92'
        b'8[\xb7/\xe8d\x83\xed\nC)\xda\xcf\x9c\x9d<L\xe9\x12U=\xe3\xef\xa3`\xec\xb7\xa4\x89\xc7-\x88\x91\xaa\xdd\xe7\x9e\xb8\xca\x1b\xf1\x12\x1b-\xe3\xd9-\t\x19\xed9\x86"<\xea]\x95\xaf\x02\n\xa2\x9b!X'
        b':: \xdd\xca\x1f\xc1\xc1\xd6yP\xf6\x85ug\t\xe1ik\xa8\xf2\xe6O\xbe\xd9\x7f\x126\xdb\x8e\xf4h\xba\x9bQ\xff,\xc6x\x99M\xcc\x8bLj\xc0\x95Y\xd7\xe3#5\xd6A\xb1\xbf\xc7v\xf3\x03\x85\xb9\xe9\x00'
        b":\x81\xda\xdc\xe6\x8e\xa6\xbf\xc5+(D\x14`\xb9\xe8>\x90\xd2\xa4+x\x99Srg\x1f\xd3Wr\xfb\xd5<\xd4D\xcb\x87\x93\xfb\x99\xfc6\x0b\x02\x0eA\x9d\x7f\xdf\xa3\xb7\xbd\xe0\xf4s\x87\xcc\xae\x83J7R'\x8e"
        b"bv\xf1R\xbf\xc5\x88\xce\xccA>\xca\xf32\xda\xffaq\xa0!\xa9\xa8\xbb\x1d\x8b\xca5\xd1\xed\x8c\x00S(\xaft?'t\xb0\x15\xb5o\xbc\xbd:\xdb\x02#\xce,\xc3S\x98\x9c\x18t\xc1g6w\x81T\xa9\xaf"
        b'7\xc8\x9a\x05\xa0"\xfc\xf5\x9e\x0e\x9cX5\xe5\xe7\xc4\x8d1C\xa3>\xa3\xc3\xee\x8fI_\xce|\x07\x14\xc6\xb4\x18\x99=hX\xb7e,\xf67\xec\xe6z)\xf3\xdd\xd1\x05e\xf5\xfa\x00\x84\xc1t#\xee\xeb\xa9&\x03'
        b'(#\xccN\xca\x9b\xf4\x1e\xc8~k\xe4\xd4:5}F\xbb\xe3\xea\xbbQ\n\x1e,\xbe[\xb1\xed\xb9\xf2\x7f\xe3\xf3!7y\x96\xbaI(\xd7\xa901\xe4W\xb7\n\xe8z\xde}\xbc]\x05\x1d\xd0\xe5r9\xbcQ\xb6'
        b'-\x94\x0e23\xb7X\x81z\r\x89/\xed\xd5w\xa8\xc4;\xba\x91\x10\x9dq3\xc5)\x0b<}UB\t{l=\xdb\xf8_(\xbb\x0b\x89^6\xb0$\x04tHt\xab\xc1Nxb\xa4/\xc9\x91.;\x1a\xa9\x19'
        b'T\x1a\x96\xc2\xb2\xf3W(=\x0e\r\xf9\xed=;\xd0\xc7!s\xb5\x86\x98\x1b\x177t13\x0b\xac2\xcbR\xfd\x97\xe8\x07\xf2J\x16`&\xaa\xc5o\xe8\x11\xf5\xb6whZ\xb34\xcd7\xcf\x85\x06\xabb&qH'
        b'\x01\xd8\xdd\x93w\x81\xe6\x02\xa0\xb8\xdcaW\xcbt\x17\x1a\xf4\x19\xfd\x7f\xc3\xa0\x00t\x95<\x92\xaa\xa1o\x1a\t-\x05\xff51\x17\xbdAS\x86\xce$1"Iy>\x0f>\x06\x80\xf3E\xcc\xb8\x93}j\xe4[\x16'
        b'\x1f-}6\xd4\xa5\x17\x9e4\xa8+\xdfZ\xbb}~\xe79 \x13O<\xf1\xf6`\x0fg\xc5Y\x17+_\x97\xc1\x13\xd3+\xf4C\x9d)-F|M\x06\xeb\xee\xb4 \x0e\xf8\xf6zB\x19O4C=\x02s{\xb7'
        b'\xf8Q\x04\x0c\xb4\xf7\xa8\x12{Yw\xe7\xbe\x9d\xb1\xabg\xc5\x97\x07a\xdd\x8d\xe2\x9fa\x16i\xe4%\xd9\x89l\x0f\xec\xfd\x12c\\H\xcb\x95\xf5\x80d\xa9\xcf@\xec\x85\x89\xbd\x0f\xa9\xca\x8c\x82\xed\x9b\x8a\xd2\xf9\xa8V'
        b'/\nW*_5\x1d5NJ?\xa2\x0c\x06\x06R\xe8\xc541\xc5Y\xb6\xee\x17n\xe0e\x94\x85p\xd5Q\xde\xee\x01\xaa\xeaY}Z\xf9\xd8\n&\xe2#\xfc\x11\x15\x97\xae\xff\xfc\x96\x88\xdap\xea\xfb\xf3\x99\xc7\xcc'
        b'U\x8fz\xd5\x8c\xadW\xf0_\xd8MA\xbf\x9b\xab\xd1\xbd\x1c\xa5\xd2S\xa1 \x08\xd9+|H1\xb6\x07\xe6\xcc\x11\x8b\xf1\xf3\xe1\x85\xb2\xceA\xa8\xb6\xf4.\x1e\xe2\x8e\x9c2\xa5h\xb4\x0e,\x01`\xb3\xba\xbd\xc6l%'
        b'\xbdL\x04\xb0\x89\x91K5\xfb\xa7\xbc\xf5\xb8h\xb9\xcf\xa8ZA\x86\xed[\xa7~\xb8\xb1O\x0e\xe8w#6\xcd4\xed\xd4\xaa\x89\xe3\xd3\xc5n\xb1\x8a\x81yV\xca\xd5&\x89\x0e/\x00\x95 \xb2\x89\xb0\x00CAq\x98'
        b'\xfb\x13i\xd9\n*q\xaf\xc2\x00C\xb1\x932\xb1\xb5/5\xe7\xfd\x1a\x87,h\xa9\xf4\xac\x8e\x86\x9d\x9d\xd3\x9a\rT\x900\xa4\xd8\x08\x83\xa2\x98!\x17\xbc\x1b#\xe7Y\xb8]\xa2I\xd3\xe0}S\xa5\xe1GMpl'
        b'n\x04\xf1\x03aU\xc8\xf9\xb2\xafm\x0eF0\xfbn\xe9\xd0\xcex\x13j\x0b\x1a9\xadk\x94r\xfe\xee\x0b\x8a\x08\x96\xd3>\xd8\x1a9n\xc9\x82JU\xb8\xc3\x7f\\X\xb3\x01J\xe5BM\xe6\x1c\xfb\x19{\xefK\x98'
        b'\xb4Sb\xad\xe7\x91\xaf\xe1#+\xc1\xd8\x8c\x91=H\xf9\xf3\x81s\xb1\x01k\n\xfa\x15\x08\x14\xda\xcfwK]\xb3_\xc5\x87\xbe\xb8S\x92zE.R {\xec\x83\xf7O9\xa9\xbe\xb7\x01\xab#\xc3\xe5\xf8G\xe4\xbb'
        b"\x0c\xceG\x95\x81\xd6(\x19_@\r\xa7\x8b\x03\x8d\xb6\xc7g\xd3'oC\xee\xc5\n\x94V\xbeE[\x1f\xd9\xa53L\xd1\x84\x05-v:\xbd\xd5\x07s\x1e\xa0\xc0\x98\xfe_\xe8\xc1y{\xb4\x80\xd6\xf5e\xa7\xf4O)"
        b'[\xf6\x08\xc4\x85\xcaf\xeex\xe0}\x04\xf6\x94\xa6\xceG\x15K\xf9\xfe&e\xde\x87\xe5\x8d\xe8R\xcf\r\x87\xeeP3\xdcyWV\xfa\x8d:\x99"\xbd20c\xcf0xi\x88\x93UWgT\xec\x12%\x94\xdc\x9c'
        b'Y\x02\xac\xa3B\xe7\x95\x8e\xfc);\x11* \x9f\xc0k\n\xe56g~m=.\x05L\xc0\xf7\xecPY\x1a0d\xe6\x06\xa1T\xc1KP\x88\xac\x04\xed\xcf9\xe4\xd8\x92c|@a<0\xed\xe3O\xf4\x8dj\xe5'
        b"g\x17\xb4}\xf9\xd5\x1f\x8c\x06'|2\xa7\x80\xda\x8c\xf6{\xd7J\x03w>\x8c`\x18\x1c\xb5C\x90\x00\x1b4D6!\xd9\xbc\x12\xf8I{$\x85D_\xa7\xcaC\x08p\xbb\xbaf\xaa\xdf\xe16\xc5\x81\x01\x13\xcb\x83"
        b"\xe1C\xc0\xd8\xb6sq\xb5\xca\x14\xdb\x06aZ\xc4<\x1f\x02+\x03<\xe5\xd9\xa3C\xeb7M\xae\xce\xe1\xc8c\xae\\P\xa1.6\xf8\x11\xf8G7\xd7\xf3\xebog\x01u\xa4F\x94)\xcf'y\x83V\xc3\x124\xb3"
        b'\xf4\xec\xbd\xc6\xde\xf9\x82\xe9z\xe7\xe3\x1b\\\xa8\x18\x0c\xf8\x02\xfe\xa6\x94\xd9\xa6\xc0\xd5\xc3S\x1b\nm\x9f\x16=\xce\xf6\x03(\x18\x066\xb5\xae@\x0f\xf6\xf0\x0fG\xa5\x90\xeahn\xeb\xfci\x9d\x1a\xbe\xa2/\x99\xcb\x8b'
        b'\xc2\xef3\xcf\r}\xc3Z\xe5\xfe\x0f\xdc\xe6\x97\x98x\xed\x91\xdbQg\xfe\xed \xca\x99/\x06\xc94\xec\x84\xfb\xbfi{o\x93\xddM\x86\xef\x90\xb8\x16\x1c2\xd5/\x9e=f[F\xe7\x92\xcd\x89\xc6.\xdb\xb7\xc6\xc8'
        b'1\xaf\x83\x08\x8a\x91\xaac\xdd\x90A\xd6\x0bo#E\x8b/\x9e\xf6\x15\x0e\x16\xd9\xa5~\x89\xd7d_\xe8e\xc9/\x98_\x02\xa3,\x1cPR\xd3j\xa0\xab\x9a\x88\xf8eb0\x8d1\x9e5<\xf2\x19X\xb7\x11\xfc\xf0'
        b'\xff\xce(~@\xcb\xb2\xe8\xcb=q\x8c\xda\x8b-\xae\x1bA\xa8\xb6\xb6\x85\xfd\xd1Y\xc2\xc4\x8d\xd1\xa1\x1d\x92\xc9\x0c\xa1\xa8"\xec\x1bi^\xc8%\xa1\x98\xb6\x0f\xd5\xb1\xd0gD\xe7d\xe9\x1a\xe5DF\xc3\x97\xf3U\xbf'
        b'n|\xf5F.\xc8\x10xT7(\xb8p\x1f.2(\x14N\x91\x83d\x11KW\xd8\xd8\x8bKtB\xaa\xeeE\xc9\xac\xd2\xdc\xaay\xdbG\xe6\x83\x10C\n#<b<\xa8+\xd3\x08S\x8ee\x8a[\xcd\xf3,\xcc'
        b'\xe7\x8d\x03\x0f\xd6\xba\xbb\x8b$b\xeb\x865\x9b7\xfa\xb1\x9f\re\xb0\xa6\xf2\xddT\x99`\xa7\x12\xd4\xd6\xe7\xaf\x7f\xf9\x08!o\xae\x87U\x01&|\xf7\xc4\x8bQ!\xe3)\x16\xff\x85w\xc1/\x96\x12\x02\xe9j|\x02'
        b'S\x12E\x88.\xd2\xbaN\xb9*G\xe9[\xd8\xdb\xd5C\xc0\xe3c\xdc<c\x88\xa3\xe3/X\xd8\xd9Sb&g\xf8$\xc6\x13\xd4\xbb\xc5\x92\xb1\xa2\xc2\x8e\xb8&\xa6:\x91E\x93\x82\x9a\x0e,\xdc&\x9fz\xc3\x16\xc6'
        b'\xd4\x04\xe1\xa0\xec\x14\xd8\xb3G\xc8=\xf7}\xa87\x11LM\xfa\xa8V\xef\x1cg\xd8Y\x9d%\xd3.PA\x01\x82\xa4\xc8\x91\x9eK<\xf3o\x0b\x07;\xb8\x8em}\xaao0\xbe\x8e+\x87\xb8\xdd\x02\x8e\x9b{7\xbd'
        b'X\x90\x0f\xd3\xefk\x91(Y\xc6\xfe\xae\x12"\xa6\xe2\x08e\xdb\xef\x9b\x19#O\xe2\xee\xd6\x1c\xb9\xa0\xec\xe3\xb2\xbea\x14bl&\xde5v\xe0\xf5\nP\xeb\xcev}H\x12\xd1\x868\xa2>j>S?y&\xd0'
        b'\xb8\xa9\x05\xc1a\x9d%+3\x1e9\x9b\'j\x83\xb2\xa0a\x91\x88\xeeL\xc9\xfc\x14#\x14l\xe6\x03\xd3"zS\xfax\xd7y\x90\x07\x06\x86q\xf3!\xd3G\x1d\xfa\xb7\xe6\x82|9\x1e\x03es6+\x04\x81/\xd0'
        b'^8\xd6\x86\x99s\x12q(\xc03\xc0d-\xca\xda\xefa\xb7\x9c\xe7\x94\x927\xe0E\x1eshT\x9b\xe2z\xe3\x1b\xc8\x12\xf8\x81%\x0c=E\xd2\xfb\x82>\xe09\xd7\x026\xda\ry \xac\x195\xf41#\x11\x05'
        b"\xf3GeVIZS8\x06qu\x91@$\xf3\xd7\x05'-\x85r9my\xf2\x1f.\x01\xee\xc5\x98\x82_\xb9\xfd/\xc1]\xbc\x1c\x91\xfd\x98v\xcb\xb4\xcc\xd4\xa0&\xec\xd1K4\xb8\xa8\xd9\xf8!K\xe8\xd1\x1e\x1c"
        b'"\xd9i\x98\x13\xcc}\t\xfb+\x0f\n\xfa \x08\x01-\xf7\xaa\xf43\x1d\xc4\x185J\x93\xed\xedt\xfb\x9c\x19\xbe}S\xa0f<f\x173"\x9f_\xf3\xb1\xfc\x01\x13\xe8\x1e\xe5\x05\x9a/4\xb8)P\xfcO\xcd\xb3'
        b'h\xdc[\xd1\xb9\xa8Q\xe4\x97\xf9\x11\xf3\xba\xb5PV\xab\xc0FmN\x92K\xa1\x0e<\xb5\x1f=\x99\x02$\xaa\xb2\x0e\xc3r\x1dsjh\xab\xf1\xb6N\xb7w\xc1\xc9%\x0f\xd7\xdb@\xdd\xb0\x19\xc3!x\\~\xa94'
        b'\xb5j\xeb\xe7\x0c\x96\xd3\x93A\x9a`be=">\xdej\x1f&\xca\xe2\xd1zNv\xb1\xa8(\xc9\xc5F\xdc\xd7Tt\xdb\xa8\\\x14J:\x98\x86\x1br\xde\x04\x87\x1b\xc5\x9bUYa\x9a3o\xb1/\t\x94\x83\xd4'
        b'\x81b:\x97Y\x95\x88\xb4#Z\xbf\xdf\xdc\xa9\xa6\x00\xcdC`\x13Y\xfd\xae$J\xdf\x00\xc8\x94\x98\xfbp6\xe4\xb1 (\xce\xa6 \xe0\x9c\x84\xd2]\x1e\t\xd0%|\xe1\xf2\xd3~\xfao\xaa\x87\x82\xf2\xd5\xdb\x06\xa6'
        b'[\t%\xfdvk\x8b,\xa2\xc5v\x94\xba/\x05!\x9e\xc97\xb2\x970n\xde\x185\x93\x94\xc2Z*\xc5W{\x01o&,Yg\x16\xcf\xd7\xc8P\xd7\x1b\xa8\xab\x8bP\xb7ag>\xf2>\x02u\xdc\x00\x84l6'
        b'K\x16z\x0f\xceN\xfb\xb6H\x07\x14\x81\xee\xedy\x8b\xef\x92\x0f\xe8\xaf\xdb\xb2\xdd\xa8\xb7\x04\x97\xb8\x05h{w\nz\xbck\xbeB\x95\xf9e9\xa8\x00\xb6 \xc0\xf4\xcb\x1d#|\x96\x97y\x8b\x08e\x89\x17T\xe6\x8e'
        b'\x8e-\xe5\xe4f;\xaf{\xbd\xc7\xb5S\x18\xbc\x8a\x1al\x82t&\xf4M\xaa\xc5\xa1\xc5Y\xc4\xb6\x97Y\xa2H \xfeF\xe5\x9dL\x0f\xcf\xcc\xfd\xba\x0f\xedB\xeaH"\x18\xd5W<<M\x8a\xac{*#\x9fn\x1e'
        b'(o`\x18\x01\xe2=.\xbf\x97\x8b>\xb3[\x1b\xa3\xb3\xdf\x9c\x13A<\xb2\x97C\x90\xe1\x91\xe6VXk\x82\xd4g\x06\xf9\xfb\xda\xe5\n/\x94\x17K\x81\xd4\xdfC1\x85\xacJ\xf5\xea[3N85\x87\x07\x9c\x11'
        b'\xa6l\xbeOD\x0bns^\xaf|\xfa\xabP\xa3\x1f"\x82GC\xa1\xe4\x13s\x1c\x00\xb0 \xc4\xf9\x13\\\xd2\xfc~\x15N1+\x1c\xf7\xb8\xa3\xe7Rg)6\xe8^\xe3\xd3n\x8c\xd1\xa7\x0e\x9cO\x13\xb7\x1bKl'
        b'\xceX\xeex\x1fNR]\xc9q(>N\xa8\xc8bQ\xd0\xba\xea\xd0\x1d\xef|.H/\x0f\x0c\x8fY\xc4\xb7OK_\xc6\xafp\xaa\xca\xc2\xa2\x03p\xa3\x1f`\xae\xa1JAG\xf2\xa7"\xde\xb6\x8d\xac\xbd\xb7\x9cG'
        b'\x845\x97\xe2\xb1\x9fX^\xc1]\xad\x84\x97_\x84\xde5z7\x9b\x9ek|\x04\xdb\xa1?{at\xd9\xf7z=\xbas\xfcF\xb9\x1e\xbcm\xad\x83Xd\x95$\x8c\xd5\xc5\xe0\x0bj\x89S\xb5\t 5\xf3\xee6\x93'
        b'\xc8C\x06yoeX\xa7\xa7\x9d\xe1\xf6%\xcb\x93\xae\xc2\x10\x9a\n\xd2\xe6\xe6\xb3.\xa7[\xc7h\x89>\x7f\x03\xadv\x8e|\xb5m\x1d{\x9d\xcd\x85\x833};\x05J\xa5\x1f\xdfF\xf1\xdf\xf6w\x8a\xd2\xe9\xc9)\xcb'
        b'~y2\xdd\t\xe5\x93\xeeM{\x8f_\xf5\xe3\xf5a\xffb;\x9f\xae\xcb\xf8\x1c6d@!\xad\xad\xb57\xbb\x8eaC\xe2+\x8f\x95\xd48\xae\x81bO\xef\xf7\xd1I\x8b\xd6$m\x1b\xf6\xddI\xf8\xb6W\xb9&\xa3'
        b'\x05W\x93\xadw\x9b9\xca\xb0BCa\x1b(\xfd\xaf\x9d\xde\x86~[\x14W\x9er!\xb9\xd4\xa6\x16k.\xdd|\x93\xe3\x11\xcc@\xe3\x00\x06`\x06\xad\xe5\x91\t]c\xc8?0\xd1T\x0f\xd0\xa2\x9dq\x83\xb8 \xcc'
        b'a\x9bp\xf8iv\x80\t\x15U\xd0\xc8j9"\xb9\x8c\xe5\xb51&\xb3\xb9\x8e\n\x10z\xa3\xdd\x8a\x8a\x07\xea\x93\xc2&PE\xb1\xbd\xe0\n\xb3\xe7\x82\t\x9f\x11\xe4\x12\xf6\x80\xce\x1f\x0b\xbf\x912y\xa7\xc4K\xbf\xb6'
        b'\xaeY\xacz)Y\xba\xa3"2\x8b\xe5o\x03\x92\r\xbb\x97\xd8z\xad\xdc:\xf0\xf2}\xd1y\xbb5\xdaO\xd4\xc0\r\xe2\xa4\xf7Y\x97 \x1eDP=\xa9<\xff\xe1n\xd5\xe4\x84\xb2\x06\xd4\tz\x7f7\xaf\x8f^N'
        b'\x7f\x8a\xef\xd4\x19T\x00n\xd8\x02-}\xb0\xdaRv\xaf|\x84\xc4d\x08\xe1\x18\xef0-\xbf\x86/@\x9e:\xef\xa4\x1b\xd3\xcc\xf7n\x83\x11\xe5\xa2\xc9d\x0c\x88\xef)\x91\xf5=\xa4X\xecHs\xf5\xeb\xc3aG\xc4'
        b'\xdag\xf6\xfa\xff\xb8\xcf\x10\x05\xdfE7\xfc\xd3\x04<\xf6c\xd5v}\xe6\x89\x8b\xc0,^\xf0\xdc\x8f@\xfe\xd9\xd7\xd4\xf3\xee\x8f\x95\x9a\xb9\x12[\x13\xa35\x1c\xbe\xa0\x94@\xfa5.zk]>\xd0\xb3\xe7@\xe93'
        b'\xac\xf3\x0eR\xdc\x11<\x1b\x8aG\x16O\x0c4\x038\x97g\x19\xdb>\xf2\xcd\xd6h\xf3\\\xc0\xfag\x1b\xcc\x9b\xda\xf1\xb7\xbb\xa5\xe7G\xac~$\rJE\xae\x16\xe8\xd9\xb5\x10T[\x9a\xe1l\xff\x01|(\xae\x06\xaa'
        b'5#\x11\x039Uq+v\x19\xb1\x13\xa1\x0e\r\x04\x97~W\x99nsQ\x08X4\'>\x9c1\x14\xd6\xcf\xf2nJ"\xc8\xd3\xce\xff\xdb\x0bJC\xaf3\r\xa0\x88^\xc1?S\xa9\x92-j\xab\xb8\xb4\xa3\xdd\xb7'
        b'\x11\xe3\x9e\xbfY\xe9IO\xe6\xec\x15\xd6\xceh\r\xf1\x13N\xf9\x12M\xdf\xff\r\x19\xeb@\x89\xceG\xd3\xd6\x7f\xc3]\xe0\xff\x0f4u\x0e\x8f\xf3O\xfe\xda\xd0\x8a\x93\xcc\x9bi\xee\xa5@\x80M\xe8_r\xc2\xb3\x00\xc0'
        b"\xcek\x90\xd2\xc6\x87j\xf4eV9z\x86'\x89\x01s\xa8)\x92c\x05T=\x84\xc4\xdb\x06l&n\r{\xd3\xe7\x03\xc9\x17\xc0\x0f5;\x99\x0b\x1dc\x19-\xc0Z\xcb\xa5\xea\xcc\xe5\x86s\t\xc6\x0b4\x9a\xfa\\"
        b'\xbf%\xfa\xbd\x07\xc1\xc9\x93\x7f\xce\xd5"<\xfe\xf3\x97\xd2\xde%\x9e\x07"\x1c\xe4\x90>\x82 \xb6\xfaq\xae\x88:\xd5\x0c;\xcd\xc0\xa2y\xaa\xd9}\xda\x99\x17\xe7?o\x08\x88\x9b\xf0\x1cH\x1a\t\x0e\xb7\x7f\xe1\xe6\xc0'
        b'\x06\xb1\x91AiC\xaa}\x00\xc5\x0c\xa9\xbcgj9\x1e&53\xed\xb0Q^\xb0\x1an [H\xfb\x8b\r\xffA\xc5~;*?\xf3\xc6\x1f\x03!\xcfHC\xe8z\xe2?\x13 \x87I\x16C01\xc3\xcbT8'
        b'jy \x89\xa9\xe3\xfd\x12\xebB\xea\x06|\xffv\x87\x1d\xbe\xa3K\x10\xf8OJ\xb9iqF\xf2\x81\xf3\xefmuT\xae\t\x18\x8e\xd5T\x12\xc6:\xdc\xd5T\x13^\x87\x9d\x8a\x9a\x8b\xaa\xcf*\xa7\xed1\xda\xf3\x0c\r'
        b'o\x1eio\xa4k\xd5\x84\x05\xfc\x8e*\x80\xda\xf3\x81\xf3\xa8\x0fk\xda\xe1\xd5\xd1gn\x0cKB\xf1\x1a\xc1\xd9Y\xa1yQ\x85\xd6h\xb2\x01\xa4\x04-v\xc2t<\r3\x9a\x1e\x02\xc0\x90\x18\x927\xa2\x1d\x90\xb0y'
        b'\xadD:k\x0e8>,\xfcE\xb6\nukC\x89\x02\x10`\xb6h\t\x8f|\xd9\xca \xb1q\xc4\xc4\xa4&\x02CS\xf9lH`=i\x18*L\xb4\xae]\xce\xd0\xb6?Xp0\x85y@\xda/\xea\xfb\xd1\xf5'
        b'\xa8\xe3L:\x87IvQ;\x98\xc5\x93\x89]\xaf\xf1\x84\x8a6.\xef\xc9#\xceR\x97\xc7\xb9Y+I\x91\xe8J\xbd\xb8\xecW.@jM\xce^\x95\xfa+\xbb>\xef\xc0C\xc1`i\x8e\x18\xf8\xbc\x1bs\x90>\xf7'
        b'\x94`\x050Y\x84\xdc\xd2z\xdbe[\x99\xac\xbf>}\xc2&_9\xd4\x82\t:\xac\xcbF\x92\xe6^\xb4=\xf4\\xq\xb0\xab\x8fT\xcc\x07P\xef\x12;\xd2,\x97\xaf\xdd\x15<!^\xa7\xb1\xfe\x7f\xe5\xed{@'
        b"\x00#Z7\xaa|\xd9\xdb\xe8\xbf5\x10+9\xe2\x1f]\xcb\xe4\xa0\x86\x835\xce\xa5'-\t\xf9\x83N\x0f\x02t1>Y(\xe2\x9b\x14\x97~\xd0 \xfc\xa12\x91~R\xd4\\\x01\xcc\xfe-6f\xebP\xdb\x02\xc1"
        b'\x82\x02\x0f\x03.\x83U\x9b\x1f\x11\xfb\x10\xcd\nDI\xc7\xe1pJg\x8e\x04"\x91}\xce\xe2\xbe\xcc\xea\xf6\'\xb0\xc4Cy\xe9L\xb1\x08\\\x05n\xfc4.]\x9f\x07\xefr^\xb7\xd6 \xf8\x96#_\xc7\xc6)\x7f'
        b'P\x0e\x8d\xbd\x85vE=\x03\xf2n*\x08D\x9a\xbd.\xc8\xa1\x15hN\xfb\xef\x92\x03\x86C2\xce\xb1\x07\x93\xcd\x81P\xd6\xe5\xff\x1d\t<\xf5%T\xd1\xf7D\xad\xbc/]c\xdf\\\x99\t\xc9\xbb+\x11\xc7\xb9b'
        b'H\xf6\xea\xfa\xc3\xcf\xd8ky\xb0\xc2\x15\xf4N\x14m^\xbam6^\xfc\xee3s{b3l^.\x94\x8e\xd3\xb8\xcaB\xd6h\xac0`\xd0\xea\xa6\x8a\xfe\xcfB@;s\xdf\xe7k~\xadh\x84-\x1b\x88\xf0\xc2'
        b'g\xa0lFh\xd5\xf7\x9e&\xf4F\xea\xbe\xedx\xee\xcc\x98S\x9dW\x7f,;q\xcb\x1dB\xc6\xeb\x1d\x03\xe2t\x90\xbcye\xab,\xfe\xa2~S\xce\x84\xc5\xadnz\x95\xdf<\xdb\n\xf5\xf6\xba\x81\xeb1\x9e\xa6b'
        b';&@\n\xc2\xc9q\x8d\xe7k6\x15,\xbb\ro\xffaf\x989\x150\xc9\xb7%\xe0t\xf6\r\x83\xd3Qp\x01\xb4Q\t\xc9b:\x87j?\xd2y\xb6\x14)\x80%\x00\xd4\x90\x91j\r\xf2W\x80\x14M\x0bP'
        b"\xb5\x8d\xaa\xbc\x13\x80\xb8c\xc8\xcc\xa7\xb6\xe7\xda\xbe[\xab~\xa0\x1b\xd8\x80\x9c\x12\xff\xf3#\xd61\x0e\xcf7T\xad\xaa\x91\x12\xf7|\x03\x0b\\\xb3a\xff\x9a\x18\x06\xfa\x84\xa1\xbb\x82\xe5\xa9p\xce\xd2\r\xe0'PC|"
        b'\xb8\xad\xfa\x8d\xa5q\xa2\x06\xc2\xc8\x15V\xef\xc2\x9c\xf5Y6\x03hA\x07\xa3\xcc\xfb\xae\xdcv\xdb\x0c\x83\x04ZI\xdd:\xd4\x0f\xbe,\n\xbdd:\xb03C\xbf:\x8a\x821|\xadB+\x8d\xb5dm`\xf1J\xb4'
        b'\x8b\xec\x81\x9b\xa4hF\xc3\x00\xe4\xe1\xe9\x1e6\xa9\x11\xc3(\xc8\xd6\xe9\x11\xd1\xc0y+)#G\xf4\xd4y|\xc5\x9dBM4\xc7\xa6\xbc\x00\xc8\x12\x97E]}\xb3\xe2|\xb9\xcb2h\xd7\xdd\xb4\x16`\xefK\xfc\xc2'
        b'\xcd?\xf8\xde\xc6\xa8$q\xd6"$O\'\x00\x10\x91:\x05\xb9I\xfe\x0c?\xfeu\x9a\xabX\xb8$zpz\xec\'\xc3\xda+]>\xd0Zo\xedMkW\xc9k\xc1\x8e\xd4[\xc9\xbd}s\xf2fv\x15\xbe\x83\xe7'
        b'\xbbg\xb9\xa9o\xb4+\x8b\x82\xcb\x01\xc57v\xb1\xcb,]_[\xed\xd4\xb5\xb8=M\xbb\xff\x8a\x8ei6\xe3\x13V0\xe4Q\x0cC\xee\x89o\x99:\x8e\xbe\x87\x8c\xe5c?\x08\xdd\xc4\x14xm\x99\xd0`\x8a\xce\xa7'
        b'\x8d\xdf\xf0:\xb8\xfde\xa5l\xd9T\x1byJ*c\xc1\xd0Q\xea\xe6&\xbc\x80M\x8co\xd4*\xb5\x83I\xc7\xf9\xa6\xab\x17|\x836Gj\x9e\xaf\x9f\xb1BG0\xbeC\xfb\xad\xc6\x81\xee7Q\x97\xc9+\xbbF\xb9'
        b'jy\xc9?x^\x11\xf3\n\xa6\x02~\xaf2\xc7\x1a\xa6F\xa6^\xcdi\xbb\xdc\xa6\xb0\xe4DKf6J\x9eS\x86\xfb\xd3\x16CR\xd3\xe1\xe2\xb7\x8c\xb5\xbe\xcf\x07\x17\xc9\x85\xd5\xd5d\xed<\x04\xe0j\xc20\x84\xdc'
        b'\x8b\x8c~\xb9\x9c\xef\xc2\xeb\xde\xf0$\xb9\xf3\xa6\xa8}^i\xe0\x9e\x03\n\x10\xf9\xce\x93\x05\x8b\x08:w\x13\xb3:!\xad\x89\x83\x992\xb6\xe84\xc2cf\x0fi\x06&e\xb2\x031i\x820h\xf5\x93\x01\xb3.\xdf'
        b'\x0e\x8b\x17\xb1\x8fU\xdf|;\xfa2\xa4H<5=\x8d\xc8v \xda\xa0\x15\x1bW\x0e7\xb9\xbf\x83\xe1\x06\xbcv!CF\x8d\xdd\x1b\xb4)a\xf1\xd8\xad\x8e\xde\x94\x12\x8aA\xf7b\xdd] Q\xcf[\xaa_\xe2\xea'
        b'U\xa9S\xf2\xd3\x80\x1a\xc6\x0c\xea9r\x8f\x92\xa1t\xd1^\x89/\xb220\xd5\xce\n`W\xfe\xfd\xa6\x1ekh\x94\xbdUw3\xfe\xed\xa9\x8a\xc2\xba\x99<\x8cy\x8f/0\x8a\x1f\x02\x13\x9f\x9c=\x11\xb8^\x87\x06'
        b'\xdc6\x92\xe1D\x1d\x9a\xb4#\x9dI\xa5\x81\xe4AD\xaet\xd5\xef\xa9E\xde\xae\x0b\xdf$\x98\x80/iH4\x15\x0c\xa5\x9c\xc2yuZt\xde\x8d\x99-\x1a\xca`.\x18\x82;+L\xb9\x9a\xe4\xc7H\x8f\xa8\xae"'
        b"\x8c\x0c\xca*\x08\xde\\\xa9\x84\xa9\xcb<\xd0\xa2\x0by'K\xa6\xd6\xf3\x9b\x15)\xc7\x89\x9e%%\xd2\xf1\xe0~\x8f+&j\xd1c!\xab\x83uF\x11)\xe0\x82\x7f\xa9\xa9S\xf4=\xb6\xe3o\xbe8q\xd9\r\x86\xb0"
        b"\x15o\xc4\xafB\xb5uKv\xc8\x1b\x06\x00n\x94+\xba\x11'\xddf\xd1\x0c?\x90\x1a\x1a\x1a\x83\x16\xfdZ<D3le\xaf\x94\xa7\x03\x02w\xc7\x04*\xdbo\xbbxr\x84\xb0\x0cX{\x9c;\x1bV\x07\xa4\xb1\xcb"
        b'?>\xa1Y\x0b\x18\xb9\x83D\xb3k\xfb\xe5i\xe7r\xde\x96\x0c\xc9\xff\xae\x94\xf3\xe8\xf7\xf4\x1a\xea*\xaf\x04\x178\xb4\xf5\x00\xe4-\x90\xa5e"\xf8\x88\x90d\xb9\xe3\x0b\xf2qo\x9f\xf2x\x93\x9c\xf8\xed\xa4\xb5<n'
        b'\xc6\xca@\xbd\xbb6\x0c\xc7\xdf\x1e7\x9a\x90\xc5\x9dH\xfe\xce\xcbla\xea\xe4\x00\x15\xe8%\x9et\xc5\x9f\x0b\x18\xb0\xb4\xb1>(b{\x98\xbaE+Y\x949\xa1\x08\x12\xe4\xee\x0bK\xad\xad\xf4~1\xd4\xb0\xf1K\xe0'
        b'\xac\x89Q?\x99br\xf1\xa7\xa1L\xf0(q\xfab\xfc\xe2\xf0\xf9\x109x\xde\xaa\xaf\xdcq\xe6,\x81$\xc3\x0c\x12\xf9\xb6Q\xe1\xf9m\xf81C\x1a!\xf9\x88\xd3L\x92bg\x14h\x95\xd8?`#\x88\x13\xcdl'
        b'\xc8n\x11\xda\xbb7\x10%\x13\xe4\xc3\x7f<\xab\xe8hOe\xee\x9a\x9c\xa5\xba{\x00\xc2\x93\xa1>Qxu\x03\xc7\xcd>\xd7\x86"\x12\x1b|S\xd8\x84\x18\xe7\xdd\x99\x16\x91\x7fq\x81x>\x0e\xdb\x19n\xbab\x9b\x8b'
        b"\xc63'\x1b\x99\xc3\xd9\xc0\xdd`\x9b\x9c\x01{U RO\x1f\x8d#\xaavQAA\xef\x18\xff\xb9ei\xe0\xc4\xceF\x9c\\\xba\xc1\x80\xbe\x8d\x07{\x9d\x1fL\x1a!\xbb\xbc\x83\x1a\xa3\xa6i@\x08\xae\xfb10!"
        b'\x8dl\xd6\x0c\xaa\x11\x9f\xf02O"\xb6n\x03\xb9E\x9b\xa7b\x9b\xdf\xfe\xb2\xee\x12\xc92t\xe5<\xcf\xf9$\x95)6<-3\xf3\x8dW\x9c2\xc1\xe8e\xe2\xa4e\xd1\xfe\xb6\x08\xd3!M\x9b\xc8\x8fh=\xe6Z'
        b'\xc5\xcc%\xd3\x1a\xfbWb\x82\x08\x02\xef\xed\xe3\x1c\x9ck_+\xc1Y`\x10X.\x0f\x00\xe9\xf8\x88\xf8\xba\xc8*++\n\xcb\xaa\x9b.\x10\xd1\x00\x85MW\x91jH\x9f\xd1Yy\x8afA_\xcc\x90\xb5\xe2Y.'
        b'\xae\x02p}{\x1dS[\xc8\xfcK\xd3\x98\xfa\xc4\xc7Rq\x17\x95TfD9\x83\x8a\xea\xf5R+k\x0c\xd0t:\x06\xb2\xb6\xfaP\xf6\xc0oj\xfc9\x0b\x89\xb0\xbe|\x80\xa6F!\x8b\xa5=\xd30\x1a\xcd4\x07'
        b'\x87\xe1h\x14\x1e\x9a\xd3\xc7\xb8Aud\xa3v:\xfcEJ\xd4\xe1\xe6\x98\xf9\x8c\x87\xed\x01p\xd3\xa8\x9f-\x98\xf3\xdbKuqp"\xfe\x9f\xeb\x10\xd6\xae\x1b/\xe89\xc4\x08:\xbe\x7f\xdd\x19"q:\x0fE\xfe\x97'
        b'\xc7\x9d<\x01\x0b\x84[ \x98\x95\xf2\x84L\x9d\x94\x87+\xdc\xaf\xb9Nz\x03\x03\x1a\x1f\x1aH\xbcf\x07\xdcT%\x1c,\xbcH\x0f\x1f\xa8=\xd6\xb6AM\xa9\xccbm\xb6h0\x15\xfb\x18\xd9W\x86\xbd\xfa\xc2Xr'
        b'Z\xf9\xdf*rWX@a\xef\x9el\xca\xd3L\x8cw\xbb\x199G\x9f\xdf\xa6\x8c`V\x0b\x82K\xaf\x84i\xbdP\x81-K\xfe\xdc\x9bV\x86x\xe6il|\xdd\x82\x83\xd0\xa62=DpfI\x04\x9c\xef\x07\xc3'
        b'9\xabMN\x0b{?\xe4\xf1\xbd\xafv\x9c\x05\x14\xeb/\xc2\xe3y\\@W\xd5\x03\xd1\x06\xcdL\xe2\xd31\xaaL\x82\xad\xb6\xf2E\x0c\x16c\x88\xa1NQ\xe9\xa9\x0e\x13\xe7\xe8\xfaFQ\x16\xe0]#\xfes\xf3\xf4\xe2'
        b'\xf3\xc0\xc6\x85E\xe4J\xb9\x82\xba\xf1)\x19\xf0\x8f{l\xaa?\xa4\x10\x8c\x18\x1a\x96-~\xb2\xdfQ\xab{\xe0Tg>\xc6Irf\x7f\x0c:v\xcd\x94\\\xe1\xc7\x93\xbd\xcb\x8a\x8c\x8eN\x8cW\x82\xe6:!jl'
        b'\x0b\xda\xab\xf32\xab<\x15\x10z\xe3\xc9"\xfa7O\xeba\xb7\xfd[e\xb2\xc4\x94mi\x1ao\x0b\xcc\xe7\x0b?\x94aS\x18\x04&\xb0z@\x06k\x044R\x1c\xf6r\xf0\xc5\x8d\x11\x99\xba\xd7\x95\xf6S\x8c\x7fH'
        b'\x1d\x9f\x98\xf5\xa8r\x96?\x05\xd5\xcd\x99>\x96\xe7fQ\x86W\x1d\xa0D\xf9\xe4\x0f\xcaL\x00\xb8\xb6\x0e\x87^"7\xe0J\xe5X\x98\xed\xff\x90)p\xd8\xc0\xbe\xa4\x97\xa6J\xed\x08\xae\x05\xa0\x07\x87@\xca\x8b\x02E'
        b'\xf7\xe6\xfe\xe7\xda\x15\xba}7\xd4\xf8\xf8\xc3LyV\x93\x9a&\xc7\xb7@N\xdf~\xedA\xef\x7f\xb9\x80\xcb\xd7\x9e\x9f\r\x1d29\\\xd6u\xc6\xa7\xf2\x80\xe1\xfb\xcc\x8fd\xa5\xb5\xd4\xbd\x0f\xf4<2r`T2\xff'
        b"G\x1dN\xbc\x12\x99\x7f\xe1,}3\xe7S\xfe\x9c)F+QJX\x86`\xe0\xb8\x14\x00\xb2\xe5\xf6a531\xac\xc3\xf3AZ\xa8^c\x16\x11O\x04'.\x8f\xe3\xaeS\x03\xa4\xcdO\x89\xfb\x00V^+\x86D"
        b"#,I_\x82k\x0e\x9f\xd0\xb7.\x18\xbf\x18\x86\x06\xfc\xd5\x7fc\xd2,\x12'\xe4^EL\x15gG\x07\xa1&\xf6#r\xbe\xe8\xee\x0ep\xebj{-\x83\xeb'\xcc\xd5\x0f\xc9\tn\xc8\xfd\x99}\xee\xc6\x80;\xfe"
        b'\x03\x9dy\x9e\x11z\xa9(o\xa3\x18$\x88c\xe5F\x08\x02{\xcd\xa7\xf8mG\xa1\xbaWJ\x98z\xeb\xff\xeb#\x8a\xb5d\xf5\xf7\xf2\xf3\xc1\x1d\xee\t|\x9c\xb7\x91\x8c\xfc\xcb\xea\xfb\xc8\x99`\x18\xdc]uk-\x14'
        b'5\x14\x01@\xd1\xc4\xb5\xde\xf2\xeb\xd3w\xa2&l\x95\xcb\x13\x8fA%\xcc\x9f\x9e\xe7\xfd\xf9\xdbq\xa4*\x00M\xd7(\xb5ex\xc5\xd6\x8apw\xccQ\xe4\xc6\xbb\xdf.\x9c,\xd6\xf3\x109s)v\x9dpQk\x8a'
        b'bAO\xc4`\xc5\xces\xc6<\x9fK\xf6\x04\xf2\xcb\xbb\xe4\x8f\x03\xcc$[\x1f\x96\x1fxA\x91\x11\xfe\xfb\xf0`\xe1\x00e\xca\x1d\x1cUC\x99}0\x85\x06"q$\xb1\xbeuU\x93\xb0GuC[\x08z\xb4\x9f'
        b'\xea\x1c\xe8Z8w\xfc\x1e\x95\x9d\x11!\xdcY\xbc\xf8\x17\xda\xdcB\xb7\x01\x94\x05\x18\x1a_6 =N8\x80\x92hM(\xd1\x85\x86\x9d\xc1\x94\xad\xf5f%\x89c\x83\xa8gY\xbbx\xc7@fa\x87\x9aNU\x1d'
        b'~\xec\xf3\x8b0\x9b\xac\x08\x86\xf0\xab\x94F )5p\xedM\xc5I/\xd1pn2H\x8d_;\xa1C\xf5\x9e\x8b\xffg\x91Y\x82\xb3\xe8\xb7\xe4\xcf\x81\x1fu\xc2\xa1\xe7\xc6<ZE-\xfaU2\xa28\xc7\x83\x89'
        b'\x9dW\x83^3\xad\xe7P\xb7\xf7.\xbd\xa2\xb4?{\x14\x0c\xf5\xf1\x94\xb4\x1cR\xa7\xfd\xa4\x13\xcfP\x17X(\x0cp\xe8\x83\xc5YW:U\x84o\xea\x9e=~88\x96\x08\xd7\xe0\xbdXF:\xc3^\x89T\x08\xc4'
        b'U|d\xe1u\xf0\xa9~d\xce1*o\x855\x9e\x9e\xb7\x00\xf4!\xfc\x98\x9bb%r\xfb\xd6{1\xaa\xc7Y\x00r\xd9Q\x0fh\xf6PK\x12H+A\xb3}\x8eK\xc1\xd7\x82\xa1\xad<)\xd0\xd0\xb6\x16a-'
        b'KN$\xf7z+7CZ\xf97\xd2M{\xb0>`\xae&\xa1K\xe9E\xa1\xd3/\xda\xbc_\x16$\xb5a\xb7!\x9a!\x1e=\xe2\x06\xa1\xb8\x9a\xc9\xa6J\x93\x0b$+Br\xd3\xc6\xaf\xdf\x96\x97\x8e\x0e\x05\xacc'
        b'\xee=9\xd3\xcc\x9a_k6H\xdb\x8cc\xf7\x0c?\x9fl\x13\xe9\xd5\x82\x9c\x18\xc4H(\xefcHQ0\x87\xed\xe2\xe0x&p)\xed\xa8\x05\x14-\x04\xc4:\x1e\xac\xdf,\x85\xe0\xc8^~$\xaac\x06Q}z'
        b';^\xf1\x18\xad\x83Bk\xa7\x1bij\x95c\xf8\n\xe9\x84\xea\x8fW\x92\x8a\xb4\xef\xd3\xbe\xdd\xe6\x12IJO\xcf\xd3\x0e\xf9"\t\xb2\xefV\xf3\xdfDy\xef\xffG\xb1\xc9\x06v\'=\x1fx\xcf\xf3C\x99\xa2.k'
        b"\x88\xaf\xed\xb6n\xca\xab\x1bvhX\xac\x8b\xefr9\x95\x81\n\x8d[r$\xaf\x07\x83HIS%\x0f\xac\x89\xec\xa2\xf9v\x9d2,\x9a\x8aFW\xd2\xebwh\xd7\x13\x8e\x11\xb9\xa3\xf2,'\x95\x06\xb0\x03\x81Q\x1f"
        b'|\x9f[\xb4e\xa5\x04\x13\xa1#!\x9b\xa5v\xb7e\xc5\xaf\xae\x03|\x94c\x00!$\xb4\xfeQWT\xa2\xa2?\x10M\xbb\xb2Ecs\xaf\x83*1\xf6\xcf\xc7\x10\xd2\xea~\xf9M&\x80\xbd\x01_\x9e\xe4s\x80M'
        b'\x80\x1e=\x0e\xf3\xa2\x87\x86\xf5\x98S&S\xe1\'\xb7b\x9f\n$\xdb"\x04\x86\xf0P\x97q3\xbf\xd1\x00\xdb\xccN\\Y\xd6V\x17\xb9\xf3\xcb\xcd\xf3"\xd5G_E\xaa\xd6\x8bf\x800[\xa9\xf162\xb2\xdd\x16'
        b'G\x10QF<\x06g\xe3\x9e\xfaGy\xa5R\x94=\xe9\x089\x1a+\xfb\xf9B\xcf\x02\x15{\xa2s\x08*\xff_u\xbd\x12NS\xd8\nF\xb73]6\xf3\x87\xe7\xc0B\x04\r~\xaa+\x11\xc2^\xb6\xfe\x8d\x83j'
        b'\xbd\x82\xb4\xc74^\xb6@\xc9Q\xe4\x9c\xc1k\xd6\xec\x11\rU]\x8d,\xf8\xd3\xe1\x0e\x0cq\xd6\x07\t\x86}\xf1\xb9]\x0b\xa9D% \xeb\xad\x8d\xdc\xf4\xc5\xce\xc0\xfe\x04\x8cy\xd1\xb9,r.\xbc\xd9a\xfa\xab1'
        b'\xb0g\x1a\x8eD\xee\x0eh\xb01_cl\xf7\xb1\xfeJ\x02\xc7\xe2\x0b\xd9\xc1\xdb\x16W\x8d\x16)V?\xc4\xfa\xeb\xe5\x02\xaf\xee\xa0\x86$8\xd0_\xab\x1fpE\x8cM\xa6\xde\x7fa\xd9\xb66\x06Z\x88BR6$'
        b'\x012\x03Ep\x0b|UP2\xe0\xfaM\xae`\xca\r\x87\'i\xfb\xf25/\xf4`E7y*\t\xcbl\xdd\x87G]\x12-\x05\x93\x8cO\x90\t\x04\xa0]H\xe5~\x14\xea\x9a\xdew7}"\xa9<\x8f\xb0u'
        b'\xbbJ`6\xdf\x8d\xec\x97zd\xb7f0\x92\xac\xed\xfacT\x9e\xf0C\x08\xf7\xf4\xe5\x93,\xbb\xe0`\x1f\x80Y,2]\xbc\xaa\tBv#x(\x1clZ\xc9\xa9x\xfd>\x15$\x177\x91\xc1\x83#\x15?\x1c'
        b'\xf4v-o\x91\xb9u\xd0\xa2\xe4\x08\x8f\x88\t\x08bQ\x87\xb8\x16\xf1\x0e\x11(\x11\xa8\t\xae\x8b\xfe\x91\x07\t \xb3@\xc74Va=\r"\xf5\x0f?\xedL\xd0\xed\x1f\xcc\xb9\x9f\xd4\x0b\xe5\x96\x003\xcd\xa5\x90]'
        b'i\xf8y\xd2\x8c$\xad\xefJTU\x14}\xfc\xf0\x19\xa2{\x98\x19\xda\xf4\x99\xa6!tEdR\xf1\x0c\xf2c\xb8\xadN\xed\xfc\x80#nl\x14n\xa2\x02L\xdc\xad1br\x05\xdf\xf9<W\xa7v72\xe0\xf2i'
        b'\xff\xce]\x1b\x96\xf6f,\xae\x05\xf9\xc5\x04\xad\x8dZ\xf6\x9b\xb5t\xd8\xf3\xfb~\xfb\x83\xf98\x1f\x03\x89\x8a:CS\x9e\xfb\xf7)\x7f\xd1H\xd6r\xf7?\x14cv\xf6\r\xd0\x9c\xb2\x1a\x0f4\xc4\xe3\x97\x1d\xc9I\xac'
        b'7\x9co\x89\x92\x9a\xf7+;S\xb9\x91:c\x81An/n\x14^\xc6\xc3\x89q\xc01t\x8e\xda\x15\xa1\xe1\xcd\xc6\x12{\xa6\x1c\xf2\xe7J\x9b\xfa&6\xbb\xe6\xc3\x94\xe9#G:V\xe0\xe4o\x062\x80\x9d_o'
        b'\xac8*&\xc4I!\x17\x0bO\xb4\x98(\xa3yb\xdd4\xe4?\x15\x8a\xd4\x95H\xc37\x90\x11+\xcb\xdcx\xab5B\x92\x1b\xe4\xe1\x800E]\xdb\xa4\x95WlQYf\xa0\xd6\xaa\xe3\xc3\xba\xc9\xbb\x89\xc4\xed\xa3'
        b'\x9c\xf7\x8b\xda\x8e\xdfH\xf2\xa2\xc5\x11\x8e|\x19(T\xef\x95\x14x\xa7+\xc0\x9bn\xbe\xa0\x12G\xf0R\x94qo\x1a\x07\xc8`\xcd\r\xab\x8dgqc\xd3\xcd\xa9h`\r\x824\xd68/\x11S\xbfq#Y\x85\x9e'
        b"\xa9\xb2\xa8\xa6\x17Nn\x05\xef\xe4\x10G\xc3\xd6\xaft\xc9\xb5\x14\xe7\x1e\x86\x7f\x934\xa9\xd44\x03q\xdd\x1f\xaf?\xea'\x12\x89G{\x05\xc1\xc5\x8c\x80?;,\x02y\x1e;\xc1q\xa1[\x90\xd0Q\x07\xf6\x05\xce\x1c"
        b'\xf7A\xeb\x18\x97=\xc56;\xe8\xf4\xd5\x1c\x1e\xcc\xa2\x11\x7f&\xa0\xc4wq\x12\x92y\x9b\x9e\x0b\\\x88\xad4;B\x85X\xfe\x15\xf8\xea\xde\xc5\x1e6\r\xb6\xbb\x13\x17\xce\x1a\xd8P\xd6P\xafd\xa6\xff\x8a\x8eB\xde'
        b']Wj\x13\xcf\xc2r\x88\x1d\xd4lz\xbfaF\xc8l%!\x04\x0c\x91\xd4\xe5\xe3\xc2\xaf\xe3\xbab\x9f\xa0\xc6h\x8b\xb5\x8c\x9c\xc9\\\xd5^\xeb\x90\x16\x9d\xb8Y\xea\x07\xbc\xf1\xfd\xc3\x17\xfa\xd5\xa5\x0em13\x8cv'
        b'\r=Z-\xe5\x9b\xcd\x1a\x9b\xf0\n\t\xe0\xb2G\xa8\xc1\xf7\x85B\xcep\xd6\xa8( \x0f\x1ceE*|\x0b \xa1\xde#\xdf\xeb\xa2\x86\x95W\xdc\xf2\xc6\xa7\xee5\xb92\xbfiU,p\x05\x92\x07\x1d\xd6a\xeb\xaf'
        b'wa\xf5\xa8\x02\x9f\x0c;#R\xfb\xc4\xc1\x9e\x8f\x94\x0b\xd1\x13\x0e\xc8S\x8e\xa9+ \xee:7\xf7*\x8dg\x93Et\xa8tn\xfd\x92F\xe7\xc38\x90b\xdd\xb2*\xcd\x82\x04G\xf8\xb7\\\x15\xd8x9}u\x14'
        b'\xa9\xbd\x8bx\xccat\xea\x01e\xdb\r\x90\xf0\xbf\xb3k\xde\xb3xG\xe6f\xa7vv\xbd\xb2s\xd7U\xe1\x16Th\xc7*\xb6<\xe6=\xaa\xee/"\xf4\x92\x0fr\x84\xe4\xae\r\xca\xd6\x18@\xa9(\xf6\xd7\xfe\x0c\xd0'
        b'2\xff>\xde\x84\x0b\x82\xcd\xba\x81\x9b\xf6D\x10\x1am\x9aOTF\x94D\x12$m\xe0\xdb\x8e\xe2\xdb\x8c\x89\x13\xaa\xd1\xaa\xc9\x97\xe1\xe4\x04\x9d}\x9a\xe4\x9e\xc3"r\x94~m\xbb\xff\xf4C\x0f^\x90\x80\xe6\x16\x0c\x14'
        b"\xe06&}\xaf>\xe5\x9d\x9d\xf6\x9c\xa7\xf0\xbc*\x11\xc7\xc5\x99\x15A\xee\xa0\xea\xf9C\xca\xc9\xc1RN\xc7\xcb\xf9\xac'ag\xb9\xcePS\x82\xdb\xe1,e\x0e\xd87a\x89\x9a\xa9\xfd\x06\xfd\xc6U\xc76\x0b+U"
        b'\xd6T=e\xb9\xd5m\x8b,Ps\xc0\x16g\xfers%\xd6\xab\x8b\xde\xfa\x0f\x9ct\xb7FQ{\xfbI\xa8\xb1^\xc5PsG!\x19\xd7{E\xdf\x04\x0cx\x81?\x9a\x12o\xa6K\xd1\x95\xac\xa8\xe69\xf22\x8f'
        b'\xd2t\x1c\x9e\xc2\x83\x9b~\xb6\xeb\xa9\xe8@v\x9e3#\x10q]\xa5\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name'
        b'__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08<module>\x01\x00\x00\x00s\x08'
        b'\x00\x00\x00\x02\x00\x08\x01\x06\x00\x0e\x01'
    ))
